@@ -344,11 +344,11 @@ class DBBackup(DatabaseModelBase):
             obj = parts[-1]
             container = parts[-2]
             client = create_swift_client(context)
-            LOG.debug("Checking if backup exists in %s" % self.location)
+            LOG.debug("Checking if backup exists in %s", self.location)
             resp = client.head_object(container, obj)
             if verify_checksum:
                 LOG.debug("Checking if backup checksum matches swift "
-                          "for backup %s" % self.id)
+                          "for backup %s", self.id)
                 # swift returns etag in double quotes
                 # e.g. '"dc3b0827f276d8d78312992cc60c2c3f"'
                 swift_checksum = resp['etag'].strip('"')
