@@ -13,9 +13,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 #
-from trove.common import cfg
-
-CONF = cfg.CONF
 
 url_ref = {
     "type": "string",
@@ -253,9 +250,11 @@ cluster = {
                                 "nics": nics,
                                 "availability_zone": non_empty_string,
                                 "modules": module_list,
+                                "region_name": non_empty_string
                             }
                         }
-                    }
+                    },
+                    "locality": non_empty_string
                 }
             }
         }
@@ -287,8 +286,10 @@ cluster = {
                         "volume": volume,
                         "nics": nics,
                         "availability_zone": non_empty_string,
+                        "modules": module_list,
                         "related_to": non_empty_string,
-                        "type": non_empty_string
+                        "type": non_empty_string,
+                        "region_name": non_empty_string
                     }
                 }
             }
@@ -311,6 +312,21 @@ cluster = {
                 }
             }
         }
+    },
+    "upgrade": {
+        "type": "object",
+        "required": ["upgrade"],
+        "additionalProperties": True,
+        "properties": {
+            "upgrade": {
+                "type": "object",
+                "required": ["datastore_version"],
+                "additionalProperties": True,
+                "properties": {
+                    "datastore_version": non_empty_string
+                }
+            }
+        }
     }
 }
 
@@ -349,7 +365,9 @@ instance = {
                         }
                     },
                     "nics": nics,
-                    "modules": module_list
+                    "modules": module_list,
+                    "region_name": non_empty_string,
+                    "locality": non_empty_string
                 }
             }
         }
@@ -368,6 +386,7 @@ instance = {
                     "replica_of": {},
                     "name": non_empty_string,
                     "configuration": configuration_id,
+                    "datastore_version": non_empty_string,
                 }
             }
         }
@@ -522,7 +541,8 @@ backup = {
                     "description": non_empty_string,
                     "instance": uuid,
                     "name": non_empty_string,
-                    "parent_id": uuid
+                    "parent_id": uuid,
+                    "incremental": boolean_string
                 }
             }
         }
@@ -547,10 +567,16 @@ guest_log = {
 module_contents = {
     "type": "string",
     "minLength": 1,
-    "maxLength": 16777215,
+    "maxLength": 4294967295,
     "pattern": "^.*.+.*$"
 }
 
+module_apply_order = {
+    "type": "integer",
+    "minimum": 0,
+    "maximum": 9,
+}
+
 module = {
     "create": {
         "name": "module:create",
@@ -577,6 +603,9 @@ module = {
                     "all_tenants": boolean_string,
                     "visible": boolean_string,
                     "live_update": boolean_string,
+                    "priority_apply": boolean_string,
+                    "apply_order": module_apply_order,
+                    "full_access": boolean_string,
                 }
             }
         }
@@ -605,8 +634,13 @@ module = {
                     },
                     "auto_apply": boolean_string,
                     "all_tenants": boolean_string,
+                    "all_datastores": boolean_string,
+                    "all_datastore_versions": boolean_string,
                     "visible": boolean_string,
                     "live_update": boolean_string,
+                    "priority_apply": boolean_string,
+                    "apply_order": module_apply_order,
+                    "full_access": boolean_string,
                 }
             }
         }
