@@ -19,6 +19,7 @@ import os.path
 
 from oslo_config import cfg
 from oslo_config.cfg import NoSuchOptError
+from oslo_config import types
 from oslo_log import log as logging
 from oslo_middleware import cors
 from osprofiler import opts as profiler
@@ -26,6 +27,7 @@ from osprofiler import opts as profiler
 from trove.common.i18n import _
 from trove.version import version_info as version
 
+ListOfPortsType = types.Range(1, 65535)
 
 LOG = logging.getLogger(__name__)
 UNKNOWN_SERVICE_ID = 'unknown-service-id-error'
@@ -66,6 +68,8 @@ common_opts = [
                help='Service endpoint type to use when searching catalog.'),
     cfg.StrOpt('nova_client_version', default='2.12',
                help="The version of the compute service client."),
+    cfg.StrOpt('glance_client_version', default='2',
+               help="The version of the image service client."),
     cfg.URIOpt('neutron_url', help='URL without the tenant segment.'),
     cfg.StrOpt('neutron_service_type', default='network',
                help='Service type to use when searching catalog.'),
@@ -76,17 +80,6 @@ common_opts = [
                help='Service type to use when searching catalog.'),
     cfg.StrOpt('cinder_endpoint_type', default='publicURL',
                help='Service endpoint type to use when searching catalog.'),
-    cfg.URIOpt('heat_url', deprecated_for_removal=True,
-               deprecated_reason=HEAT_REMOVAL_DEPRECATION_WARNING,
-               help='URL without the tenant segment.'),
-    cfg.StrOpt('heat_service_type', default='orchestration',
-               deprecated_for_removal=True,
-               deprecated_reason=HEAT_REMOVAL_DEPRECATION_WARNING,
-               help='Service type to use when searching catalog.'),
-    cfg.StrOpt('heat_endpoint_type', default='publicURL',
-               deprecated_for_removal=True,
-               deprecated_reason=HEAT_REMOVAL_DEPRECATION_WARNING,
-               help='Service endpoint type to use when searching catalog.'),
     cfg.URIOpt('swift_url', help='URL ending in ``AUTH_``.'),
     cfg.StrOpt('swift_service_type', default='object-store',
                help='Service type to use when searching catalog.'),
@@ -97,7 +90,7 @@ common_opts = [
                help='Service type to use when searching catalog.'),
     cfg.StrOpt('glance_endpoint_type', default='publicURL',
                help='Service endpoint type to use when searching catalog.'),
-    cfg.URIOpt('trove_auth_url', default='http://0.0.0.0:5000/v2.0',
+    cfg.URIOpt('trove_auth_url', default='http://0.0.0.0/identity/v2.0',
                help='Trove authentication URL.'),
     cfg.StrOpt('trove_url', help='URL without the tenant segment.'),
     cfg.StrOpt('trove_service_type', default='database',
@@ -219,9 +212,6 @@ common_opts = [
     cfg.BoolOpt('use_nova_server_volume', default=False,
                 help='Whether to provision a Cinder volume for the '
                      'Nova instance.'),
-    cfg.BoolOpt('use_heat', default=False, deprecated_for_removal=True,
-                deprecated_reason=HEAT_REMOVAL_DEPRECATION_WARNING,
-                help='Use Heat for provisioning.'),
     cfg.StrOpt('device_path', default='/dev/vdb',
                help='Device path for volume if volume support is enabled.'),
     cfg.StrOpt('default_datastore', default=None,
@@ -237,10 +227,6 @@ common_opts = [
                help='Maximum time (in seconds) to wait for a server delete.'),
     cfg.IntOpt('volume_time_out', default=60,
                help='Maximum time (in seconds) to wait for a volume attach.'),
-    cfg.IntOpt('heat_time_out', default=60, deprecated_for_removal=True,
-               deprecated_reason=HEAT_REMOVAL_DEPRECATION_WARNING,
-               help='Maximum time (in seconds) to wait for a Heat request to '
-                    'complete.'),
     cfg.IntOpt('reboot_time_out', default=60 * 2,
                help='Maximum time (in seconds) to wait for a server reboot.'),
     cfg.IntOpt('dns_time_out', default=60 * 2,
@@ -331,10 +317,6 @@ common_opts = [
     cfg.StrOpt('remote_cinder_client',
                default='trove.common.remote.cinder_client',
                help='Client to send Cinder calls to.'),
-    cfg.StrOpt('remote_heat_client', deprecated_for_removal=True,
-               deprecated_reason=HEAT_REMOVAL_DEPRECATION_WARNING,
-               default='trove.common.remote.heat_client',
-               help='Client to send Heat calls to.'),
     cfg.StrOpt('remote_swift_client',
                default='trove.common.remote.swift_client',
                help='Client to send Swift calls to.'),
@@ -437,6 +419,12 @@ common_opts = [
     cfg.ListOpt('module_types', default=['ping', 'new_relic_license'],
                 help='A list of module types supported. A module type '
                      'corresponds to the name of a ModuleDriver.'),
+    cfg.IntOpt('module_reapply_max_batch_size', default=50,
+               help='The maximum number of instances to reapply a module to '
+                    'at the same time.'),
+    cfg.IntOpt('module_reapply_min_batch_delay', default=2,
+               help='The minimum delay (in seconds) between subsequent '
+                    'module batch reapply executions.'),
     cfg.StrOpt('guest_log_container_name',
                default='database_logs',
                help='Name of container that stores guest log components.'),
@@ -523,11 +511,11 @@ mysql_group = cfg.OptGroup(
 mysql_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
-    cfg.ListOpt('tcp_ports', default=["3306"],
+    cfg.ListOpt('tcp_ports', default=["3306"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -606,11 +594,11 @@ percona_group = cfg.OptGroup(
 percona_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
-    cfg.ListOpt('tcp_ports', default=["3306"],
+    cfg.ListOpt('tcp_ports', default=["3306"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -695,10 +683,11 @@ pxc_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports', default=["3306", "4444", "4567", "4568"],
+                item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -788,10 +777,11 @@ redis_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports', default=["6379", "16379"],
+                item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -865,10 +855,11 @@ cassandra_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports', default=["7000", "7001", "7199", "9042", "9160"],
+                item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -967,13 +958,13 @@ couchbase_group = cfg.OptGroup(
 couchbase_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
-    cfg.ListOpt('tcp_ports',
+    cfg.ListOpt('tcp_ports', item_type=ListOfPortsType,
                 default=["8091", "8092", "4369", "11209-11211",
                          "21100-21199"],
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -1032,10 +1023,11 @@ mongodb_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports', default=["2500", "27017", "27019"],
+                item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -1124,11 +1116,11 @@ postgresql_group = cfg.OptGroup(
 postgresql_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
-    cfg.ListOpt('tcp_ports', default=["5432"],
+    cfg.ListOpt('tcp_ports', default=["5432"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -1201,11 +1193,11 @@ couchdb_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports',
-                default=["5984"],
+                default=["5984"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -1262,12 +1254,12 @@ vertica_group = cfg.OptGroup(
 vertica_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
-    cfg.ListOpt('tcp_ports',
+    cfg.ListOpt('tcp_ports', item_type=ListOfPortsType,
                 default=["5433", "5434", "22", "5444", "5450", "4803"],
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports',
+    cfg.ListOpt('udp_ports', item_type=ListOfPortsType,
                 default=["5433", "4803", "4804", "6453"],
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
@@ -1333,11 +1325,11 @@ db2_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports',
-                default=["50000"],
+                default=["50000"], item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                 'in the security group (only applicable '
                 'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                 'in the security group (only applicable '
                 'if trove_security_groups_support is True).'),
@@ -1393,10 +1385,11 @@ mariadb_opts = [
     cfg.BoolOpt('icmp', default=False,
                 help='Whether to permit ICMP.'),
     cfg.ListOpt('tcp_ports', default=["3306", "4444", "4567", "4568"],
+                item_type=ListOfPortsType,
                 help='List of TCP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
-    cfg.ListOpt('udp_ports', default=[],
+    cfg.ListOpt('udp_ports', default=[], item_type=ListOfPortsType,
                 help='List of UDP ports and/or port ranges to open '
                      'in the security group (only applicable '
                      'if trove_security_groups_support is True).'),
@@ -1588,7 +1581,7 @@ def get_configuration_property(property_name):
     if not datastore_manager:
         datastore_manager = 'mysql'
         LOG.warning(_("Manager name ('datastore_manager') not defined, "
-                      "using '%s' options instead.") % datastore_manager)
+                      "using '%s' options instead."), datastore_manager)
 
     try:
         return CONF.get(datastore_manager).get(property_name)
