@@ -44,7 +44,7 @@ class TroveError(openstack_exception.OpenstackException):
             self.message = message
         if self.internal_message is not None:
             try:
-                LOG.error(safe_fmt_string(self.internal_message) % kwargs)
+                LOG.error(safe_fmt_string(self.internal_message), kwargs)
             except Exception:
                 LOG.error(self.internal_message)
         self.message = safe_fmt_string(self.message)
@@ -121,16 +121,41 @@ class DatastoresNotFound(NotFound):
 
 class DatastoreFlavorAssociationNotFound(NotFound):
 
-    message = _("Flavor %(flavor_id)s is not supported for datastore "
+    message = _("Flavor %(id)s is not supported for datastore "
                 "%(datastore)s version %(datastore_version)s")
 
 
 class DatastoreFlavorAssociationAlreadyExists(TroveError):
 
-    message = _("Flavor %(flavor_id)s is already associated with "
+    message = _("Flavor %(id)s is already associated with "
                 "datastore %(datastore)s version %(datastore_version)s")
 
 
+class DatastoreVolumeTypeAssociationNotFound(NotFound):
+
+    message = _("The volume type %(id)s is not valid for datastore "
+                "%(datastore)s and version %(version_id)s.")
+
+
+class DatastoreVolumeTypeAssociationAlreadyExists(TroveError):
+
+    message = _("Datastore '%(datastore)s' version %(datastore_version)s "
+                "and volume-type %(id)s mapping already exists.")
+
+
+class DataStoreVersionVolumeTypeRequired(TroveError):
+
+    message = _("Only specific volume types are allowed for a "
+                "datastore %(datastore)s version %(datastore_version)s. "
+                "You must specify a valid volume type.")
+
+
+class DatastoreVersionNoVolumeTypes(TroveError):
+
+    message = _("No valid volume types could be found for datastore "
+                "%(datastore)s and version %(datastore_version)s.")
+
+
 class DatastoreNoVersion(TroveError):
 
     message = _("Datastore '%(datastore)s' has no version '%(version)s'.")
