@@ -17,6 +17,7 @@ import abc
 
 from lxml import etree
 from oslo_log import log as logging
+from oslo_utils import encodeutils
 import routes
 import six
 import stevedore
@@ -25,12 +26,10 @@ import webob.exc
 
 from trove.common import base_exception as exception
 from trove.common import base_wsgi
-from trove.common import cfg
 from trove.common.i18n import _
 from trove.common import wsgi
 
 LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
 DEFAULT_XMLNS = "http://docs.openstack.org/trove"
 XMLNS_ATOM = "http://www.w3.org/2005/Atom"
 
@@ -125,7 +124,7 @@ class ActionExtensionController(object):
         self.action_handlers[action_name] = handler
 
     def action(self, req, id, body):
-        for action_name, handler in self.action_handlers.iteritems():
+        for action_name, handler in self.action_handlers.items():
             if action_name in body:
                 return handler(body, req, id)
         # no action handler found (bump to downstream application)
@@ -191,7 +190,7 @@ class ExtensionsResource(wsgi.Resource):
 
     def index(self, req):
         extensions = []
-        for _alias, ext in self.extension_manager.extensions.iteritems():
+        for _alias, ext in self.extension_manager.extensions.items():
             extensions.append(self._translate(ext))
         return dict(extensions=extensions)
 
@@ -304,7 +303,7 @@ class ExtensionMiddleware(wsgi.Middleware):
 
     def _map_custom_collection_actions(self, resource_ext, mapper,
                                        controller_resource):
-        for action, method in resource_ext.collection_actions.iteritems():
+        for action, method in resource_ext.collection_actions.items():
             parent = resource_ext.parent
             conditions = dict(method=[method])
             path = "/%s/%s" % (resource_ext.collection, action)
@@ -362,7 +361,7 @@ class ExtensionManager(object):
                                     extension_resource,
                                     serializer=extension_resource.serializer)
         resources.append(res_ext)
-        for alias, ext in self.extensions.iteritems():
+        for alias, ext in self.extensions.items():
             try:
                 resources.extend(ext.get_resources())
             except AttributeError:
@@ -372,7 +371,7 @@ class ExtensionManager(object):
     def get_actions(self):
         """Returns a list of ActionExtension objects."""
         actions = []
-        for alias, ext in self.extensions.iteritems():
+        for alias, ext in self.extensions.items():
             try:
                 actions.extend(ext.get_actions())
             except AttributeError:
@@ -382,7 +381,7 @@ class ExtensionManager(object):
     def get_request_extensions(self):
         """Returns a list of RequestExtension objects."""
         request_exts = []
-        for alias, ext in self.extensions.iteritems():
+        for alias, ext in self.extensions.items():
             try:
                 request_exts.extend(ext.get_request_extensions())
             except AttributeError:
@@ -398,7 +397,8 @@ class ExtensionManager(object):
             LOG.debug('Ext namespace: %s', extension.get_namespace())
             LOG.debug('Ext updated: %s', extension.get_updated())
         except AttributeError as ex:
-            LOG.exception(_("Exception loading extension: %s"), unicode(ex))
+            LOG.exception(_("Exception loading extension: %s"),
+                          encodeutils.exception_to_unicode(ex))
             return False
         return True
 
