@@ -20,16 +20,12 @@ from trove.common import exception
 from trove.common.strategies.cluster import strategy
 
 from cinderclient.v2 import client as CinderClient
-from heatclient.v1 import client as HeatClient
 from keystoneclient.service_catalog import ServiceCatalog
 from novaclient.client import Client
 from swiftclient.client import Connection
 
 CONF = cfg.CONF
 
-PROXY_AUTH_URL = CONF.trove_auth_url
-USE_SNET = CONF.backup_use_snet
-
 
 def normalize_url(url):
     """Adds trailing slash if necessary."""
@@ -103,7 +99,7 @@ def nova_client(context, region_name=None):
                     bypass_url=url,
                     tenant_id=context.tenant,
                     project_domain_name=context.project_domain_name,
-                    auth_url=PROXY_AUTH_URL,
+                    auth_url=CONF.trove_auth_url,
                     auth_token=context.auth_token)
     client.client.auth_token = context.auth_token
     client.client.management_url = url
@@ -132,29 +128,12 @@ def cinder_client(context, region_name=None):
 
     client = CinderClient.Client(context.user, context.auth_token,
                                  project_id=context.tenant,
-                                 auth_url=PROXY_AUTH_URL)
+                                 auth_url=CONF.trove_auth_url)
     client.client.auth_token = context.auth_token
     client.client.management_url = url
     return client
 
 
-def heat_client(context, region_name=None):
-    if CONF.heat_url:
-        url = '%(heat_url)s%(tenant)s' % {
-            'heat_url': normalize_url(CONF.heat_url),
-            'tenant': context.tenant}
-    else:
-        url = get_endpoint(context.service_catalog,
-                           service_type=CONF.heat_service_type,
-                           endpoint_region=region_name or CONF.os_region_name,
-                           endpoint_type=CONF.heat_endpoint_type)
-
-    client = HeatClient.Client(token=context.auth_token,
-                               os_no_client_auth=True,
-                               endpoint=url)
-    return client
-
-
 def swift_client(context, region_name=None):
     if CONF.swift_url:
         # swift_url has a different format so doesn't need to be normalized
@@ -169,7 +148,7 @@ def swift_client(context, region_name=None):
     client = Connection(preauthurl=url,
                         preauthtoken=context.auth_token,
                         tenant_name=context.tenant,
-                        snet=USE_SNET)
+                        snet=CONF.backup_use_snet)
     return client
 
 
@@ -194,5 +173,4 @@ create_guest_client = import_class(CONF.remote_guest_client)
 create_nova_client = import_class(CONF.remote_nova_client)
 create_swift_client = import_class(CONF.remote_swift_client)
 create_cinder_client = import_class(CONF.remote_cinder_client)
-create_heat_client = import_class(CONF.remote_heat_client)
 create_neutron_client = import_class(CONF.remote_neutron_client)
