@@ -30,39 +30,64 @@ class VerticaGuestAgentStrategy(base.BaseGuestAgentStrategy):
 
 
 class VerticaGuestAgentAPI(guest_api.API):
+    """Cluster Specific Datastore Guest API
+
+    **** VERSION CONTROLLED API ****
+
+    The methods in this class are subject to version control as
+    coordinated by guestagent/api.py.  Whenever a change is made to
+    any API method in this class, add a version number and comment
+    to the top of guestagent/api.py and use the version number as
+    appropriate in this file
+    """
 
     def get_public_keys(self, user):
-        LOG.debug("Getting public keys for user: %s." % user)
+        LOG.debug("Getting public keys for user: %s.", user)
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("get_public_keys", guest_api.AGENT_HIGH_TIMEOUT,
-                          self.version_cap, user=user)
+                          version=version, user=user)
 
     def authorize_public_keys(self, user, public_keys):
-        LOG.debug("Authorizing public keys for user: %s." % user)
+        LOG.debug("Authorizing public keys for user: %s.", user)
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("authorize_public_keys",
-                          guest_api.AGENT_HIGH_TIMEOUT, self.version_cap,
+                          guest_api.AGENT_HIGH_TIMEOUT,
+                          version=version,
                           user=user, public_keys=public_keys)
 
     def install_cluster(self, members):
-        LOG.debug("Installing Vertica cluster on members: %s." % members)
+        LOG.debug("Installing Vertica cluster on members: %s.", members)
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("install_cluster", CONF.cluster_usage_timeout,
-                          self.version_cap, members=members)
+                          version=version, members=members)
 
     def grow_cluster(self, members):
-        LOG.debug("Growing Vertica cluster with members: %s." % members)
+        LOG.debug("Growing Vertica cluster with members: %s.", members)
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("grow_cluster", CONF.cluster_usage_timeout,
-                          self.version_cap, members=members)
+                          version=version, members=members)
 
     def shrink_cluster(self, members):
-        LOG.debug("Shrinking Vertica cluster with members: %s." % members)
+        LOG.debug("Shrinking Vertica cluster with members: %s.", members)
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("shrink_cluster", CONF.cluster_usage_timeout,
-                          self.version_cap, members=members)
+                          version=version, members=members)
 
     def mark_design_ksafe(self, k):
-        LOG.debug("Setting vertica k-safety level to : %s." % k)
+        LOG.debug("Setting vertica k-safety level to : %s.", k)
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("mark_design_ksafe", CONF.cluster_usage_timeout,
-                          self.version_cap, k=k)
+                          version=version, k=k)
 
     def cluster_complete(self):
         LOG.debug("Notifying cluster install completion.")
+        version = guest_api.API.API_BASE_VERSION
+
         return self._call("cluster_complete", guest_api.AGENT_HIGH_TIMEOUT,
-                          self.version_cap)
+                          version=version)
