@@ -15,7 +15,6 @@
 """I totally stole most of this from melange, thx guys!!!"""
 
 import collections
-import datetime
 import inspect
 import os
 import shutil
@@ -29,8 +28,7 @@ from oslo_log import log as logging
 from oslo_service import loopingcall
 from oslo_utils import importutils
 from oslo_utils import strutils
-from oslo_utils import timeutils
-from passlib import utils as passlib_utils
+from passlib import pwd
 import six
 import six.moves.urllib.parse as urlparse
 
@@ -46,14 +44,15 @@ import_object = importutils.import_object
 import_module = importutils.import_module
 bool_from_string = strutils.bool_from_string
 execute = processutils.execute
-isotime = timeutils.isotime
 
 
 def build_jinja_environment():
-    env = jinja2.Environment(loader=jinja2.ChoiceLoader([
-        jinja2.FileSystemLoader(CONF.template_path),
-        jinja2.PackageLoader("trove", "templates")
-    ]))
+    env = jinja2.Environment(
+        autoescape=True,
+        loader=jinja2.ChoiceLoader([
+            jinja2.FileSystemLoader(CONF.template_path),
+            jinja2.PackageLoader("trove", "templates")
+        ]))
     # Add some basic operation not built-in.
     env.globals['max'] = max
     env.globals['min'] = min
@@ -97,10 +96,6 @@ def generate_uuid():
     return str(uuid.uuid4())
 
 
-def utcnow():
-    return datetime.datetime.utcnow()
-
-
 def raise_if_process_errored(process, exception):
     try:
         err = process.stderr.read()
@@ -123,7 +118,7 @@ class cached_property(object):
 
     Taken from : https://github.com/nshah/python-memoize
     The function wrapped is called the first time to retrieve the result
-    and than that calculated result is used the next time you access
+    and then that calculated result is used the next time you access
     the value:
 
         class Foo(object):
@@ -244,7 +239,7 @@ def execute_with_timeout(*args, **kwargs):
             LOG.error(
                 _("Command '%(cmd)s' failed. %(description)s "
                   "Exit code: %(exit_code)s\nstderr: %(stderr)s\n"
-                  "stdout: %(stdout)s") %
+                  "stdout: %(stdout)s"),
                 {'cmd': e.cmd, 'description': e.description or '',
                  'exit_code': e.exit_code, 'stderr': e.stderr,
                  'stdout': e.stdout})
@@ -287,7 +282,7 @@ def generate_random_password(password_length=None):
         password_length or
         cfg.get_configuration_property('default_password_length')
     )
-    return passlib_utils.generate_password(size=password_length)
+    return pwd.genword(length=password_length)
 
 
 def try_recover(func):
@@ -299,22 +294,12 @@ def try_recover(func):
             if recover_func is not None:
                 recover_func(func)
             else:
-                LOG.debug("No recovery method defined for %(func)s" % {
+                LOG.debug("No recovery method defined for %(func)s", {
                           'func': func.__name__})
             raise
     return _decorator
 
 
-def gen_ports(portstr):
-    from_port, sep, to_port = portstr.partition('-')
-    if not (to_port and from_port):
-        if not sep:
-            to_port = from_port
-    if int(from_port) > int(to_port):
-        raise ValueError
-    return from_port, to_port
-
-
 def unpack_singleton(container):
     """Unpack singleton collections.
 
