@@ -18,14 +18,14 @@ from oslo_service import periodic_task
 
 from trove.backup import models as bkup_models
 from trove.common import cfg
-from trove.common import exception
+from trove.common import exception as trove_exception
 from trove.common.i18n import _
 from trove.common.instance import ServiceStatus
 from trove.common.rpc import version as rpc_version
 from trove.common.serializable_notification import SerializableNotification
 from trove.conductor.models import LastSeen
 from trove.extensions.mysql import models as mysql_models
-from trove.instance import models as t_models
+from trove.instance import models as inst_models
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -47,23 +47,22 @@ class Manager(periodic_task.PeriodicTasks):
 
         if sent is None:
             LOG.error(_("[Instance %s] sent field not present. Cannot "
-                        "compare.") % instance_id)
+                        "compare."), instance_id)
             return False
 
-        LOG.debug("Instance %(instance)s sent %(method)s at %(sent)s "
-                  % fields)
+        LOG.debug("Instance %(instance)s sent %(method)s at %(sent)s ", fields)
 
         seen = None
         try:
             seen = LastSeen.load(instance_id=instance_id,
                                  method_name=method_name)
-        except exception.NotFound:
+        except trove_exception.NotFound:
             # This is fine.
             pass
 
         if seen is None:
             LOG.debug("[Instance %s] Did not find any previous message. "
-                      "Creating." % instance_id)
+                      "Creating.", instance_id)
             seen = LastSeen.create(instance_id=instance_id,
                                    method_name=method_name,
                                    sent=sent)
@@ -73,20 +72,20 @@ class Manager(periodic_task.PeriodicTasks):
         last_sent = float(seen.sent)
         if last_sent < sent:
             LOG.debug("[Instance %s] Rec'd message is younger than last "
-                      "seen. Updating." % instance_id)
+                      "seen. Updating.", instance_id)
             seen.sent = sent
             seen.save()
             return False
 
         LOG.info(_("[Instance %s] Rec'd message is older than last seen. "
-                   "Discarding.") % instance_id)
+                   "Discarding."), instance_id)
         return True
 
     def heartbeat(self, context, instance_id, payload, sent=None):
-        LOG.debug("Instance ID: %(instance)s, Payload: %(payload)s" %
+        LOG.debug("Instance ID: %(instance)s, Payload: %(payload)s",
                   {"instance": str(instance_id),
                    "payload": str(payload)})
-        status = t_models.InstanceServiceStatus.find_by(
+        status = inst_models.InstanceServiceStatus.find_by(
             instance_id=instance_id)
         if self._message_too_old(instance_id, 'heartbeat', sent):
             return
@@ -97,7 +96,7 @@ class Manager(periodic_task.PeriodicTasks):
 
     def update_backup(self, context, instance_id, backup_id,
                       sent=None, **backup_fields):
-        LOG.debug("Instance ID: %(instance)s, Backup ID: %(backup)s" %
+        LOG.debug("Instance ID: %(instance)s, Backup ID: %(backup)s",
                   {"instance": str(instance_id),
                    "backup": str(backup_id)})
         backup = bkup_models.DBBackup.find_by(id=backup_id)
@@ -114,7 +113,7 @@ class Manager(periodic_task.PeriodicTasks):
                 'instance': str(instance_id),
             }
             LOG.error(_("[Instance: %(instance)s] Backup IDs mismatch! "
-                        "Expected %(expected)s, found %(found)s") % fields)
+                        "Expected %(expected)s, found %(found)s"), fields)
             return
         if instance_id != backup.instance_id:
             fields = {
@@ -124,7 +123,7 @@ class Manager(periodic_task.PeriodicTasks):
             }
             LOG.error(_("[Instance: %(instance)s] Backup instance IDs "
                         "mismatch! Expected %(expected)s, found "
-                        "%(found)s") % fields)
+                        "%(found)s"), fields)
             return
 
         for k, v in backup_fields.items():
@@ -133,7 +132,7 @@ class Manager(periodic_task.PeriodicTasks):
                     'key': k,
                     'value': v,
                 }
-                LOG.debug("Backup %(key)s: %(value)s" % fields)
+                LOG.debug("Backup %(key)s: %(value)s", fields)
                 setattr(backup, k, v)
         backup.save()
 
@@ -149,4 +148,6 @@ class Manager(periodic_task.PeriodicTasks):
                         message, exception):
         notification = SerializableNotification.deserialize(
             context, serialized_notification)
+        LOG.error(_("Guest exception on request %(req)s:\n%(exc)s"),
+                  {'req': notification.request_id, 'exc': exception})
         notification.notify_exc_info(message, exception)
