@@ -19,6 +19,7 @@ from trove.common import exception
 from trove.common.i18n import _
 from trove.common import models
 from trove.common import pagination
+from trove.common import timeutils
 from trove.common import utils
 from trove.db import db_query
 from trove.db import get_db_api
@@ -33,7 +34,7 @@ class DatabaseModelBase(models.ModelBase):
     def create(cls, **values):
         init_vals = {
             'id': utils.generate_uuid(),
-            'created': utils.utcnow(),
+            'created': timeutils.utcnow(),
         }
         if hasattr(cls, 'deleted'):
             init_vals['deleted'] = False
@@ -58,20 +59,20 @@ class DatabaseModelBase(models.ModelBase):
     def save(self):
         if not self.is_valid():
             raise exception.InvalidModelError(errors=self.errors)
-        self['updated'] = utils.utcnow()
-        LOG.debug("Saving %(name)s: %(dict)s" %
+        self['updated'] = timeutils.utcnow()
+        LOG.debug("Saving %(name)s: %(dict)s",
                   {'name': self.__class__.__name__,
                    'dict': strutils.mask_dict_password(self.__dict__)})
         return self.db_api.save(self)
 
     def delete(self):
-        self['updated'] = utils.utcnow()
-        LOG.debug("Deleting %(name)s: %(dict)s" %
+        self['updated'] = timeutils.utcnow()
+        LOG.debug("Deleting %(name)s: %(dict)s",
                   {'name': self.__class__.__name__,
                    'dict': strutils.mask_dict_password(self.__dict__)})
 
         if self.preserve_on_delete:
-            self['deleted_at'] = utils.utcnow()
+            self['deleted_at'] = timeutils.utcnow()
             self['deleted'] = True
             return self.db_api.save(self)
         else:
@@ -81,7 +82,7 @@ class DatabaseModelBase(models.ModelBase):
         for key in values:
             if hasattr(self, key):
                 setattr(self, key, values[key])
-        self['updated'] = utils.utcnow()
+        self['updated'] = timeutils.utcnow()
         return self.db_api.save(self)
 
     def __init__(self, **kwargs):
@@ -105,16 +106,19 @@ class DatabaseModelBase(models.ModelBase):
         if ((context and not context.is_admin and hasattr(model, 'tenant_id')
              and model.tenant_id != context.tenant)):
             msg = _("Tenant %(s_tenant)s tried to access "
-                    "%(s_name)s, owned by %(s_owner)s.")
-            LOG.error(msg % (
-                {"s_tenant": context.tenant, "s_name": cls.__name__,
-                 "s_owner": model.tenant_id}))
-            raise exception.ModelNotFoundError(
-                _("Tenant %(s_tenant)s cannot access %(s_name)s") % (
-                    {"s_tenant": context.tenant, "s_name": cls.__name__}))
+                    "%(s_name)s, owned by %(s_owner)s.") % {
+                "s_tenant": context.tenant, "s_name": cls.__name__,
+                "s_owner": model.tenant_id}
+
+            LOG.error(msg)
+            raise exception.ModelNotFoundError(msg)
 
         return model
 
+    @classmethod
+    def find_by_filter(cls, **kwargs):
+        return db_query.find_by_filter(cls, **cls._process_conditions(kwargs))
+
     @classmethod
     def get_by(cls, **kwargs):
         return get_db_api().find_by(cls, **cls._process_conditions(kwargs))
