@@ -88,8 +88,8 @@ def _create_facade(options):
                     LOG.warning(_('Configuration option "query_log" has been '
                                   'depracated. Use "connection_debug" '
                                   'instead. Setting connection_debug = '
-                                  '%(debug_level)s instead.')
-                                % conf.get('connection_debug'))
+                                  '%(debug_level)s instead.'),
+                                conf.get('connection_debug'))
                 # TODO(mvandijk): once query_log is removed,
                 #                 use enginefacade.from_config() instead
                 database_opts = dict(CONF.database)
