@@ -30,8 +30,8 @@ class HostInstanceController(wsgi.Controller):
     def action(self, req, body, tenant_id, host_id):
         LOG.info(_("Committing an ACTION against host %(host_id)s for "
                    "tenant '%(tenant_id)s'\n"
-                   "req : '%(req)s'\n\n") % {"req": req, "host_id": host_id,
-                                             "tenant_id": tenant_id})
+                   "req : '%(req)s'\n\n"), {"req": req, "host_id": host_id,
+                                            "tenant_id": tenant_id})
 
         if not body:
             raise exception.BadRequest(_("Invalid request body."))
@@ -55,6 +55,6 @@ class HostInstanceController(wsgi.Controller):
             raise exception.BadRequest(_("Invalid request body."))
 
     def _action_update(self, context, host, body):
-        LOG.debug("Updating all instances for host: %s" % host.name)
+        LOG.debug("Updating all instances for host: %s", host.name)
         host.update_all(context)
         return wsgi.Result(None, 202)
