@@ -19,11 +19,9 @@ from trove.common import cfg
 from trove.common import exception
 from trove.common.i18n import _
 from trove.common import remote
-from trove.common import utils
+from trove.common import timeutils
 from trove.extensions.mysql import models as mysql_models
-from trove.instance import models as imodels
 from trove.instance import models as instance_models
-from trove.instance.models import load_instance, InstanceServiceStatus
 from trove import rpc
 
 LOG = logging.getLogger(__name__)
@@ -38,7 +36,7 @@ def load_mgmt_instances(context, deleted=None, client=None,
         mgmt_servers = client.rdservers.list()
     except AttributeError:
         mgmt_servers = client.servers.list(search_opts={'all_tenants': 1})
-    LOG.info(_("Found %d servers in Nova") %
+    LOG.info(_("Found %d servers in Nova"),
              len(mgmt_servers if mgmt_servers else []))
     args = {}
     if deleted is not None:
@@ -54,8 +52,9 @@ def load_mgmt_instances(context, deleted=None, client=None,
 
 def load_mgmt_instance(cls, context, id, include_deleted):
     try:
-        instance = load_instance(cls, context, id, needs_server=True,
-                                 include_deleted=include_deleted)
+        instance = instance_models.load_instance(
+            cls, context, id, needs_server=True,
+            include_deleted=include_deleted)
         client = remote.create_nova_client(context, CONF.os_region_name)
         try:
             server = client.rdservers.get(instance.server_id)
@@ -74,12 +73,13 @@ def load_mgmt_instance(cls, context, id, include_deleted):
         assert instance.server is not None
     except Exception as e:
         LOG.error(e)
-        instance = load_instance(cls, context, id, needs_server=False,
-                                 include_deleted=include_deleted)
+        instance = instance_models.load_instance(
+            cls, context, id, needs_server=False,
+            include_deleted=include_deleted)
     return instance
 
 
-class SimpleMgmtInstance(imodels.BaseInstance):
+class SimpleMgmtInstance(instance_models.BaseInstance):
     def __init__(self, context, db_info, server, datastore_status):
         super(SimpleMgmtInstance, self).__init__(context, db_info, server,
                                                  datastore_status)
@@ -87,7 +87,7 @@ class SimpleMgmtInstance(imodels.BaseInstance):
     @property
     def status(self):
         if self.deleted:
-            return imodels.InstanceStatus.SHUTDOWN
+            return instance_models.InstanceStatus.SHUTDOWN
         return super(SimpleMgmtInstance, self).status
 
     @property
@@ -130,7 +130,7 @@ class DetailedMgmtInstance(SimpleMgmtInstance):
         return instance
 
 
-class MgmtInstance(imodels.Instance):
+class MgmtInstance(instance_models.Instance):
     def get_diagnostics(self):
         return self.get_guest().get_diagnostics()
 
@@ -144,7 +144,7 @@ class MgmtInstance(imodels.Instance):
         return self.get_guest().rpc_ping()
 
 
-class MgmtInstances(imodels.Instances):
+class MgmtInstances(instance_models.Instances):
     @staticmethod
     def load_status_from_existing(context, db_infos, servers):
         def load_instance(context, db, status, server=None):
@@ -152,11 +152,9 @@ class MgmtInstances(imodels.Instances):
 
         if context is None:
             raise TypeError(_("Argument context not defined."))
-        find_server = imodels.create_server_list_matcher(servers)
-        instances = imodels.Instances._load_servers_status(load_instance,
-                                                           context,
-                                                           db_infos,
-                                                           find_server)
+        find_server = instance_models.create_server_list_matcher(servers)
+        instances = instance_models.Instances._load_servers_status(
+            load_instance, context, db_infos, find_server)
         _load_servers(instances, find_server)
         return instances
 
@@ -188,12 +186,11 @@ class NotificationTransformer(object):
 
     @staticmethod
     def _get_audit_period():
-        now = datetime.datetime.now()
-        audit_start = utils.isotime(
-            now - datetime.timedelta(
-                seconds=CONF.exists_notification_interval),
-            subsecond=True)
-        audit_end = utils.isotime(now, subsecond=True)
+        now = timeutils.utcnow()
+        start_time = now - datetime.timedelta(
+            seconds=CONF.exists_notification_interval)
+        audit_start = timeutils.isotime(start_time)
+        audit_end = timeutils.isotime(now)
         return audit_start, audit_end
 
     def _get_service_id(self, datastore_manager, id_map):
@@ -201,8 +198,8 @@ class NotificationTransformer(object):
             datastore_manager_id = id_map[datastore_manager]
         else:
             datastore_manager_id = cfg.UNKNOWN_SERVICE_ID
-            LOG.error(_("Datastore ID for Manager (%s) is not configured")
-                      % datastore_manager)
+            LOG.error(_("Datastore ID for Manager (%s) is not configured"),
+                      datastore_manager)
         return datastore_manager_id
 
     def transform_instance(self, instance, audit_start, audit_end):
@@ -231,7 +228,7 @@ class NotificationTransformer(object):
         db_infos = instance_models.DBInstance.find_all(deleted=False)
         for db_info in db_infos:
             try:
-                service_status = InstanceServiceStatus.find_by(
+                service_status = instance_models.InstanceServiceStatus.find_by(
                     instance_id=db_info.id)
             except exception.ModelNotFoundError:
                 # There is a small window of opportunity during when the db
@@ -240,7 +237,7 @@ class NotificationTransformer(object):
                 # message for all such instances. These instance are too new
                 # and will get picked up the next round of notifications.
                 LOG.debug("InstanceServiceStatus not found for %s. "
-                          "Will wait to send notification." % db_info.id)
+                          "Will wait to send notification.", db_info.id)
                 continue
             instance = SimpleMgmtInstance(None, db_info, None, service_status)
             message = self.transform_instance(instance, audit_start, audit_end)
@@ -257,10 +254,10 @@ class NovaNotificationTransformer(NotificationTransformer):
 
     def _lookup_flavor(self, flavor_id):
         if flavor_id in self._flavor_cache:
-            LOG.debug("Flavor cache hit for %s" % flavor_id)
+            LOG.debug("Flavor cache hit for %s", flavor_id)
             return self._flavor_cache[flavor_id]
         # fetch flavor resource from nova
-        LOG.info(_("Flavor cache miss for %s") % flavor_id)
+        LOG.info(_("Flavor cache miss for %s"), flavor_id)
         flavor = self.nova_client.flavors.get(flavor_id)
         self._flavor_cache[flavor_id] = flavor.name if flavor else 'unknown'
         return self._flavor_cache[flavor_id]
