@@ -57,7 +57,7 @@ class Manager(manager.Manager):
             if os.path.exists(mount_point):
                 device.migrate_data(mount_point)
             device.mount(mount_point)
-            LOG.debug('Mounted the volume (%s).' % device_path)
+            LOG.debug('Mounted the volume (%s).', device_path)
             self.app.start_db()
         self.app.change_permissions()
         self.app.make_host_reachable()
@@ -92,12 +92,12 @@ class Manager(manager.Manager):
         Restores all CouchDB databases and their documents from the
         backup.
         """
-        LOG.info(_("Restoring database from backup %s") %
+        LOG.info(_("Restoring database from backup %s"),
                  backup_info['id'])
         try:
             backup.restore(context, backup_info, restore_location)
         except Exception:
-            LOG.exception(_("Error performing restore from backup %s") %
+            LOG.exception(_("Error performing restore from backup %s"),
                           backup_info['id'])
             self.status.set_status(rd_instance.ServiceStatuses.FAILED)
             raise
@@ -127,11 +127,11 @@ class Manager(manager.Manager):
         return service.CouchDBAdmin().list_users(limit, marker, include_marker)
 
     def get_user(self, context, username, hostname):
-        LOG.debug("Show details of user %s." % username)
+        LOG.debug("Show details of user %s.", username)
         return service.CouchDBAdmin().get_user(username, hostname)
 
     def grant_access(self, context, username, hostname, databases):
-        LOG.debug("Granting acccess.")
+        LOG.debug("Granting access.")
         return service.CouchDBAdmin().grant_access(username, databases)
 
     def revoke_access(self, context, username, hostname, database):
