@@ -13,6 +13,8 @@
 # License for the specific language governing permissions and limitations
 # under the License.
 
+import os
+
 from oslo_log import log as logging
 
 from trove.common.i18n import _
@@ -42,6 +44,10 @@ class Manager(manager.Manager):
     def status(self):
         return self.appStatus
 
+    @property
+    def configuration_manager(self):
+        return self.app.configuration_manager
+
     def do_prepare(self, context, packages, databases, memory_mb, users,
                    device_path, mount_point, backup_info,
                    config_contents, root_password, overrides,
@@ -51,13 +57,18 @@ class Manager(manager.Manager):
             device = volume.VolumeDevice(device_path)
             device.unmount_device(device_path)
             device.format()
-            device.mount(mount_point)
-            LOG.debug('Mounted the volume.')
+            if os.path.exists(mount_point):
+                device.migrate_data(mount_point)
+                device.mount(mount_point)
+                LOG.debug("Mounted the volume.")
         self.app.update_hostname()
         self.app.change_ownership(mount_point)
         self.app.start_db()
         if backup_info:
             self._perform_restore(backup_info, context, mount_point)
+        if config_contents:
+            self.app.configuration_manager.save_configuration(
+                config_contents)
 
     def restart(self, context):
         """
@@ -78,12 +89,12 @@ class Manager(manager.Manager):
         self.app.stop_db(do_not_start_on_reboot=do_not_start_on_reboot)
 
     def create_database(self, context, databases):
-        LOG.debug("Creating database(s)." % databases)
+        LOG.debug("Creating database(s) %s.", databases)
         with EndNotification(context):
             self.admin.create_database(databases)
 
     def delete_database(self, context, database):
-        LOG.debug("Deleting database %s." % database)
+        LOG.debug("Deleting database %s.", database)
         with EndNotification(context):
             return self.admin.delete_database(database)
 
@@ -98,12 +109,12 @@ class Manager(manager.Manager):
             self.admin.create_user(users)
 
     def delete_user(self, context, user):
-        LOG.debug("Delete a user %s." % user)
+        LOG.debug("Delete a user %s.", user)
         with EndNotification(context):
             self.admin.delete_user(user)
 
     def get_user(self, context, username, hostname):
-        LOG.debug("Show details of user %s." % username)
+        LOG.debug("Show details of user %s.", username)
         return self.admin.get_user(username, hostname)
 
     def list_users(self, context, limit=None, marker=None,
@@ -120,11 +131,11 @@ class Manager(manager.Manager):
         self.app.start_db_with_conf_changes(config_contents)
 
     def _perform_restore(self, backup_info, context, restore_location):
-        LOG.info(_("Restoring database from backup %s.") % backup_info['id'])
+        LOG.info(_("Restoring database from backup %s."), backup_info['id'])
         try:
             backup.restore(context, backup_info, restore_location)
         except Exception:
-            LOG.exception(_("Error performing restore from backup %s.") %
+            LOG.exception(_("Error performing restore from backup %s."),
                           backup_info['id'])
             self.status.set_status(ds_instance.ServiceStatuses.FAILED)
             raise
@@ -133,3 +144,15 @@ class Manager(manager.Manager):
     def create_backup(self, context, backup_info):
         LOG.debug("Creating backup.")
         backup.backup(context, backup_info)
+
+    def update_overrides(self, context, overrides, remove=False):
+        LOG.debug("Updating overrides.")
+        if remove:
+            self.app.remove_overrides()
+        else:
+            self.app.update_overrides(context, overrides)
+
+    def apply_overrides(self, context, overrides):
+        if overrides:
+            LOG.debug("Applying overrides: %s", str(overrides))
+            self.app.apply_overrides(overrides)
