@@ -125,8 +125,7 @@ class RedisApp(object):
         Install the redis server.
         """
         LOG.debug('Installing redis server.')
-        msg = "Creating %s." % system.REDIS_CONF_DIR
-        LOG.debug(msg)
+        LOG.debug("Creating %s.", system.REDIS_CONF_DIR)
         operating_system.create_directory(system.REDIS_CONF_DIR, as_root=True)
         pkg_opts = {}
         packager.pkg_install(packages, pkg_opts, TIME_OUT)
@@ -215,6 +214,8 @@ class RedisApp(object):
 
         self.configuration_manager.apply_system_override(
             {'daemonize': 'yes',
+             'protected-mode': 'no',
+             'supervised': 'systemd',
              'pidfile': system.REDIS_PID_FILE,
              'logfile': system.REDIS_LOG_FILE,
              'dir': system.REDIS_DATA_DIR})
@@ -341,7 +342,7 @@ class RedisApp(object):
             slots = map(str, range(first_slot, last_slot + 1))
             group_size = 200
             while slots:
-                cmd = ([system.REDIS_CLI, 'cluster', 'addslots']
+                cmd = (['redis-cli', 'cluster', 'addslots']
                        + slots[0:group_size])
                 out, err = utils.execute_with_timeout(*cmd, run_as_root=True,
                                                       root_helper='sudo')
@@ -424,7 +425,17 @@ class RedisAdmin(object):
         save_cmd = 'SAVE'
         last_save = self.__client.lastsave()
         LOG.debug("Starting Redis data persist")
-        if self.__client.bgsave():
+        save_ok = True
+        try:
+            save_ok = self.__client.bgsave()
+        except redis.exceptions.ResponseError as re:
+            # If an auto-save is in progress just use it, since it must have
+            # just happened
+            if "Background save already in progress" in str(re):
+                LOG.info(_("Waiting for existing background save to finish"))
+            else:
+                raise
+        if save_ok:
             save_cmd = 'BGSAVE'
 
             def _timestamp_changed():
@@ -443,7 +454,7 @@ class RedisAdmin(object):
         elif not self.__client.save():
             raise exception.BackupCreationError(_("Could not persist "
                                                 "Redis data (%s)") % save_cmd)
-        LOG.debug("Redis data persist (%s) completed" % save_cmd)
+        LOG.debug("Redis data persist (%s) completed", save_cmd)
 
     def set_master(self, host=None, port=None):
         self.__client.slaveof(host, port)
@@ -476,15 +487,17 @@ class RedisAdmin(object):
     def wait_until(self, key, wait_value, section=None, timeout=None):
         """Polls redis until the specified 'key' changes to 'wait_value'."""
         timeout = timeout or CONF.usage_timeout
-        LOG.debug("Waiting for Redis '%s' to be: %s." % (key, wait_value))
+        LOG.debug("Waiting for Redis '%(key)s' to be: %(value)s.",
+                  {'key': key, 'value': wait_value})
 
         def _check_info():
             redis_info = self.get_info(section)
             if key in redis_info:
                 current_value = redis_info[key]
-                LOG.debug("Found '%s' for field %s." % (current_value, key))
+                LOG.debug("Found '%(value)s' for field %(key)s.",
+                          {'value': current_value, 'key': key})
             else:
-                LOG.error(_('Output from Redis command: %s') % redis_info)
+                LOG.error(_('Output from Redis command: %s'), redis_info)
                 raise RuntimeError(_("Field %(field)s not found "
                                      "(Section: '%(sec)s').") %
                                    ({'field': key, 'sec': section}))
