@@ -85,7 +85,7 @@ class MySqlApp(service.BaseMySqlApp):
         return self._get_gtid_executed()
 
     def wait_for_txn(self, txn):
-        LOG.info(_("Waiting on txn '%s'.") % txn)
+        LOG.info(_("Waiting on txn '%s'."), txn)
         with self.local_sql_client(self.get_engine()) as client:
             client.execute("SELECT WAIT_UNTIL_SQL_THREAD_AFTER_GTIDS('%s')"
                            % txn)
