@@ -16,19 +16,12 @@
 
 from datetime import date
 
-from oslo_log import log as logging
-
-from trove.common import cfg
 from trove.common.i18n import _
 from trove.common import stream_codecs
 from trove.guestagent.common import operating_system
 from trove.guestagent.module.drivers import module_driver
 
 
-LOG = logging.getLogger(__name__)
-CONF = cfg.CONF
-
-
 class PingDriver(module_driver.ModuleDriver):
     """Concrete module to show implementation and functionality. Responds
     like an actual module driver, but does nothing except return the
