@@ -21,11 +21,11 @@ from oslo_log import log as logging
 from oslo_utils import netutils
 
 from trove.common import cfg
+from trove.common.db.mysql import models
 from trove.common.i18n import _
 from trove.common import utils
 from trove.guestagent.backup.backupagent import BackupAgent
 from trove.guestagent.datastore.mysql.service import MySqlAdmin
-from trove.guestagent.db import models
 from trove.guestagent.strategies import backup
 from trove.guestagent.strategies.replication import base
 
@@ -33,13 +33,6 @@ AGENT = BackupAgent()
 CONF = cfg.CONF
 
 REPL_BACKUP_NAMESPACE = 'trove.guestagent.strategies.backup.mysql_impl'
-REPL_BACKUP_STRATEGY = 'InnoBackupEx'
-REPL_BACKUP_INCREMENTAL_STRATEGY = 'InnoBackupExIncremental'
-REPL_BACKUP_RUNNER = backup.get_backup_strategy(
-    REPL_BACKUP_STRATEGY, REPL_BACKUP_NAMESPACE)
-REPL_BACKUP_INCREMENTAL_RUNNER = backup.get_backup_strategy(
-    REPL_BACKUP_INCREMENTAL_STRATEGY, REPL_BACKUP_NAMESPACE)
-REPL_EXTRA_OPTS = CONF.backup_runner_options.get(REPL_BACKUP_STRATEGY, '')
 
 LOG = logging.getLogger(__name__)
 
@@ -47,6 +40,20 @@ LOG = logging.getLogger(__name__)
 class MysqlReplicationBase(base.Replication):
     """Base class for MySql Replication strategies."""
 
+    @property
+    def repl_backup_runner(self):
+        return backup.get_backup_strategy('InnoBackupEx',
+                                          REPL_BACKUP_NAMESPACE)
+
+    @property
+    def repl_incr_backup_runner(self):
+        return backup.get_backup_strategy('InnoBackupExIncremental',
+                                          REPL_BACKUP_NAMESPACE)
+
+    @property
+    def repl_backup_extra_opts(self):
+        return CONF.backup_runner_options.get('InnoBackupEx', '')
+
     def get_master_ref(self, service, snapshot_info):
         master_ref = {
             'host': netutils.get_my_ipv4(),
@@ -58,14 +65,20 @@ class MysqlReplicationBase(base.Replication):
         replication_user = None
         replication_password = utils.generate_random_password(16)
 
-        mysql_user = models.MySQLUser()
-        mysql_user.password = replication_password
+        mysql_user = None  # cache the model as we just want name validation
 
         retry_count = 0
 
         while replication_user is None:
             try:
-                mysql_user.name = 'slave_' + str(uuid.uuid4())[:8]
+                name = 'slave_' + str(uuid.uuid4())[:8]
+                if mysql_user:
+                    mysql_user.name = name
+                else:
+                    mysql_user = models.MySQLUser(
+                        name=name, password=replication_password
+                    )
+                    mysql_user.check_create()
                 MySqlAdmin().create_user([mysql_user.serialize()])
                 LOG.debug("Trying to create replication user " +
                           mysql_user.name)
@@ -81,28 +94,24 @@ class MysqlReplicationBase(base.Replication):
 
         return replication_user
 
-    def backup_runner_for_replication(self):
-        return {
-            'runner': REPL_BACKUP_RUNNER,
-            'extra_opts': REPL_EXTRA_OPTS,
-            'incremental_runner': REPL_BACKUP_INCREMENTAL_RUNNER
-        }
-
     def snapshot_for_replication(self, context, service,
                                  location, snapshot_info):
         snapshot_id = snapshot_info['id']
         replica_number = snapshot_info.get('replica_number', 1)
 
-        LOG.debug("Acquiring backup for replica number %d." % replica_number)
+        LOG.debug("Acquiring backup for replica number %d.", replica_number)
         # Only create a backup if it's the first replica
         if replica_number == 1:
             AGENT.execute_backup(
-                context, snapshot_info,
-                **self.backup_runner_for_replication())
+                context, snapshot_info, runner=self.repl_backup_runner,
+                extra_opts=self.repl_backup_extra_opts,
+                incremental_runner=self.repl_incr_backup_runner)
         else:
             LOG.debug("Using existing backup created for previous replica.")
-        LOG.debug("Replication snapshot %s used for replica number %d."
-                  % (snapshot_id, replica_number))
+        LOG.debug("Replication snapshot %(snapshot_id)s used for replica "
+                  "number %(replica_number)d.",
+                  {'snapshot_id': snapshot_id,
+                   'replica_number': replica_number})
 
         replication_user = self._create_replication_user()
         service.grant_replication_privilege(replication_user)
