@@ -19,6 +19,7 @@ from datetime import datetime
 from datetime import timedelta
 import os.path
 import re
+from sqlalchemy import func
 
 from novaclient import exceptions as nova_exceptions
 from oslo_config.cfg import NoSuchOptError
@@ -38,10 +39,12 @@ from trove.common.remote import create_guest_client
 from trove.common.remote import create_nova_client
 from trove.common import server_group as srv_grp
 from trove.common import template
+from trove.common import timeutils
 from trove.common.trove_remote import create_trove_client
 from trove.common import utils
 from trove.configuration.models import Configuration
 from trove.datastore import models as datastore_models
+from trove.datastore.models import DatastoreVersionMetadata as dvm
 from trove.datastore.models import DBDatastoreVersionMetadata
 from trove.db import get_db_api
 from trove.db import models as dbmodels
@@ -569,26 +572,6 @@ def load_server_group_info(instance, context, compute_id):
         instance.locality = srv_grp.ServerGroup.get_locality(server_group)
 
 
-def validate_modules_for_apply(modules, datastore_id, datastore_version_id):
-    for module in modules:
-        if (module.datastore_id and
-                module.datastore_id != datastore_id):
-            reason = (_("Module '%(mod)s' cannot be applied "
-                        " (Wrong datastore '%(ds)s' - expected '%(ds2)s')")
-                      % {'mod': module.name, 'ds': module.datastore_id,
-                         'ds2': datastore_id})
-            raise exception.ModuleInvalid(reason=reason)
-        if (module.datastore_version_id and
-                module.datastore_version_id != datastore_version_id):
-            reason = (_("Module '%(mod)s' cannot be applied "
-                        " (Wrong datastore version '%(ver)s' "
-                        "- expected '%(ver2)s')")
-                      % {'mod': module.name,
-                         'ver': module.datastore_version_id,
-                         'ver2': datastore_version_id})
-            raise exception.ModuleInvalid(reason=reason)
-
-
 class BaseInstance(SimpleInstance):
     """Represents an instance.
     -----------
@@ -669,7 +652,7 @@ class BaseInstance(SimpleInstance):
         pass
 
     def delete_async(self):
-        deleted_at = datetime.utcnow()
+        deleted_at = timeutils.utcnow()
         self._delete_resources(deleted_at)
         LOG.debug("Setting instance %s to be deleted.", self.id)
         self.update_db(deleted=True, deleted_at=deleted_at,
@@ -912,6 +895,9 @@ class Instance(BuiltInstance):
         deltas = {'instances': 1}
         volume_support = datastore_cfg.volume_support
         if volume_support:
+            call_args['volume_type'] = volume_type
+            dvm.validate_volume_type(context, volume_type,
+                                     datastore.name, datastore_version.name)
             call_args['volume_size'] = volume_size
             validate_volume_size(volume_size)
             deltas['volumes'] = volume_size
@@ -982,8 +968,8 @@ class Instance(BuiltInstance):
             except exception.ModelNotFoundError:
                 LOG.exception(
                     _("Cannot create a replica of %(id)s "
-                      "as that instance could not be found.")
-                    % {'id': slave_of_id})
+                      "as that instance could not be found."),
+                    {'id': slave_of_id})
                 raise exception.NotFound(uuid=slave_of_id)
         elif replica_count and replica_count != 1:
             raise exception.Forbidden(_(
@@ -1013,8 +999,9 @@ class Instance(BuiltInstance):
         for aa_module in auto_apply_modules:
             if aa_module.id not in module_ids:
                 modules.append(aa_module)
-        validate_modules_for_apply(modules, datastore.id, datastore_version.id)
-        module_list = module_views.get_module_list(modules)
+        module_models.Modules.validate(
+            modules, datastore.id, datastore_version.id)
+        module_list = module_views.convert_modules_to_list(modules)
 
         def _create_resources():
 
@@ -1231,7 +1218,7 @@ class Instance(BuiltInstance):
             raise exception.BadRequest(_("Instance %s is not a replica"
                                        " source.") % self.id)
         service = InstanceServiceStatus.find_by(instance_id=self.id)
-        last_heartbeat_delta = datetime.utcnow() - service.updated_at
+        last_heartbeat_delta = timeutils.utcnow() - service.updated_at
         agent_expiry_interval = timedelta(seconds=CONF.agent_heartbeat_expiry)
         if last_heartbeat_delta < agent_expiry_interval:
             raise exception.BadRequest(_("Replica Source %s cannot be ejected"
@@ -1481,12 +1468,13 @@ class Instances(object):
                       'deleted': False}
         if not include_clustered:
             query_opts['cluster_id'] = None
-        if instance_ids and len(instance_ids) > 1:
-            raise exception.DatastoreOperationNotSupported(
-                operation='module-instances', datastore='current')
         if instance_ids:
-            query_opts['id'] = instance_ids[0]
-        db_infos = DBInstance.find_all(**query_opts)
+            if context.is_admin:
+                query_opts.pop('tenant_id')
+            filters = [DBInstance.id.in_(instance_ids)]
+            db_infos = DBInstance.find_by_filter(filters=filters, **query_opts)
+        else:
+            db_infos = DBInstance.find_all(**query_opts)
         limit = utils.pagination_limit(context.limit, Instances.DEFAULT_LIMIT)
         data_view = DBInstance.find_by_pagination('instances', db_infos, "foo",
                                                   limit=limit,
@@ -1516,7 +1504,7 @@ class Instances(object):
             except exception.NotFound:
                 # The instance may be gone if we're in the middle of a
                 # shrink operation, so just log and continue
-                LOG.debug("Instance %s is no longer available, skipping." %
+                LOG.debug("Instance %s is no longer available, skipping.",
                           db_instance.id)
         return db_insts
 
@@ -1591,7 +1579,7 @@ class DBInstance(dbmodels.DatabaseModelBase):
             kwargs["encrypted_key"] = cu.encode_data(cu.encrypt_data(
                 key, CONF.inst_rpc_key_encr_key))
             LOG.debug("Generated unique RPC encryption key for "
-                      "instance. key = %s" % key)
+                      "instance. key = %s", key)
         else:
             kwargs["encrypted_key"] = None
 
@@ -1672,6 +1660,40 @@ def get_instance_encryption_key(instance_id):
     return _instance_encryption_key[instance_id]
 
 
+def module_instance_count(context, module_id, include_clustered=False):
+    """Returns a summary of the instances that have applied a given
+    module.  We use the SQLAlchemy query object directly here as there's
+    functionality needed that's not exposed in the trove/db/__init__.py/Query
+    object.
+    """
+    columns = [module_models.DBModule.name,
+               module_models.DBInstanceModule.module_id,
+               module_models.DBInstanceModule.md5,
+               func.count(module_models.DBInstanceModule.md5),
+               (module_models.DBInstanceModule.md5 ==
+                module_models.DBModule.md5),
+               func.min(module_models.DBInstanceModule.updated),
+               func.max(module_models.DBInstanceModule.updated)]
+    filters = [module_models.DBInstanceModule.module_id == module_id,
+               module_models.DBInstanceModule.deleted == 0]
+    query = module_models.DBInstanceModule.query()
+    query = query.join(
+        module_models.DBModule,
+        module_models.DBInstanceModule.module_id == module_models.DBModule.id)
+    query = query.join(
+        DBInstance,
+        module_models.DBInstanceModule.instance_id == DBInstance.id)
+    if not include_clustered:
+        filters.append(DBInstance.cluster_id.is_(None))
+    if not context.is_admin:
+        filters.append(DBInstance.tenant_id == context.tenant)
+    query = query.group_by(module_models.DBInstanceModule.md5)
+    query = query.add_columns(*columns)
+    query = query.filter(*filters)
+    query = query.order_by(module_models.DBInstanceModule.updated)
+    return query.all()
+
+
 def persist_instance_fault(notification, event_qualifier):
     """This callback is registered to be fired whenever a
     notification is sent out.
@@ -1767,7 +1789,7 @@ class InstanceServiceStatus(dbmodels.DatabaseModelBase):
         self.status_description = value.description
 
     def save(self):
-        self['updated_at'] = utils.utcnow()
+        self['updated_at'] = timeutils.utcnow()
         return get_db_api().save(self)
 
     status = property(get_status, set_status)
