@@ -15,7 +15,6 @@
 
 from oslo_log import log as logging
 from oslo_utils import strutils
-import webob.exc
 
 from trove.backup.models import Backup as backup_model
 from trove.backup import views as backup_views
@@ -74,7 +73,7 @@ class InstanceController(wsgi.Controller):
     def action(self, req, body, tenant_id, id):
         """
         Handles requests that modify existing instances in some manner. Actions
-        could include 'resize', 'restart', 'reset_password'
+        could include 'resize', 'restart'
         :param req: http request object
         :param body: deserialized body of the request as a dict
         :param tenant_id: the tenant id for whom owns the instance
@@ -87,7 +86,6 @@ class InstanceController(wsgi.Controller):
         _actions = {
             'restart': self._action_restart,
             'resize': self._action_resize,
-            'reset_password': self._action_reset_password,
             'promote_to_replica_source':
             self._action_promote_to_replica_source,
             'eject_replica_source': self._action_eject_replica_source,
@@ -161,9 +159,6 @@ class InstanceController(wsgi.Controller):
             instance.resize_flavor(new_flavor_id)
         return wsgi.Result(None, 202)
 
-    def _action_reset_password(self, context, instance, body):
-        raise webob.exc.HTTPNotImplemented()
-
     def _action_promote_to_replica_source(self, context, req, instance, body):
         self.authorize_instance_action(
             context, 'promote_to_replica_source', instance)
@@ -193,7 +188,7 @@ class InstanceController(wsgi.Controller):
         with StartNotification(context, instance_id=instance.id):
             instance.reset_status()
 
-            LOG.debug("Failing backups for instance %s." % instance.id)
+            LOG.debug("Failing backups for instance %s.", instance.id)
             backup_model.fail_for_instance(instance.id)
 
         return wsgi.Result(None, 202)
@@ -470,7 +465,7 @@ class InstanceController(wsgi.Controller):
 
     def guest_log_list(self, req, tenant_id, id):
         """Return all information about all logs for an instance."""
-        LOG.debug("Listing logs for tenant %s" % tenant_id)
+        LOG.debug("Listing logs for tenant %s", tenant_id)
         context = req.environ[wsgi.CONTEXT_KEY]
         instance = models.Instance.load(context, id)
         if not instance:
@@ -536,9 +531,9 @@ class InstanceController(wsgi.Controller):
         self.authorize_instance_action(context, 'module_apply', instance)
         module_ids = [mod['id'] for mod in body.get('modules', [])]
         modules = module_models.Modules.load_by_ids(context, module_ids)
-        models.validate_modules_for_apply(
+        module_models.Modules.validate(
             modules, instance.datastore.id, instance.datastore_version.id)
-        module_list = module_views.get_module_list(modules)
+        module_list = module_views.convert_modules_to_list(modules)
         client = create_guest_client(context, id)
         result_list = client.module_apply(module_list)
         models.Instance.add_instance_modules(context, id, modules)
@@ -559,6 +554,8 @@ class InstanceController(wsgi.Controller):
             context, instance_id=id, module_id=module_id)
         for instance_module in instance_modules:
             module_models.InstanceModule.delete(context, instance_module)
-            LOG.debug("Deleted IM record %s (instance %s, module %s)." %
-                      (instance_module.id, id, module_id))
+            LOG.debug("Deleted IM record %(instance_module_id)s "
+                      "(instance %(id)s, module %(module_id)s).",
+                      {'instance_module_id': instance_module.id, 'id': id,
+                       'module_id': module_id})
         return wsgi.Result(None, 200)
