@@ -16,7 +16,6 @@
 
 """Model classes that form the core of Module functionality."""
 
-from datetime import datetime
 import hashlib
 import six
 from sqlalchemy.sql.expression import or_
@@ -27,9 +26,11 @@ from trove.common import cfg
 from trove.common import crypto_utils
 from trove.common import exception
 from trove.common.i18n import _
+from trove.common import timeutils
 from trove.common import utils
 from trove.datastore import models as datastore_models
 from trove.db import models
+from trove.taskmanager import api as task_api
 
 
 CONF = cfg.CONF
@@ -67,7 +68,7 @@ class Modules(object):
             db_info = db_info.filter(or_(DBModule.tenant_id == context.tenant,
                                          DBModule.tenant_id.is_(None)))
             if db_info.count() == 0:
-                LOG.debug("No modules found for tenant %s" % context.tenant)
+                LOG.debug("No modules found for tenant %s", context.tenant)
         modules = db_info.all()
         return modules
 
@@ -86,7 +87,7 @@ class Modules(object):
         db_info = Modules.add_datastore_filter(db_info, datastore_id)
         db_info = Modules.add_ds_version_filter(db_info, datastore_version_id)
         if db_info.count() == 0:
-            LOG.debug("No auto-apply modules found for tenant %s" %
+            LOG.debug("No auto-apply modules found for tenant %s",
                       context.tenant)
         modules = db_info.all()
         return modules
@@ -127,6 +128,26 @@ class Modules(object):
             modules = db_info.all()
         return modules
 
+    @staticmethod
+    def validate(modules, datastore_id, datastore_version_id):
+        for module in modules:
+            if (module.datastore_id and
+                    module.datastore_id != datastore_id):
+                reason = (_("Module '%(mod)s' cannot be applied "
+                            " (Wrong datastore '%(ds)s' - expected '%(ds2)s')")
+                          % {'mod': module.name, 'ds': module.datastore_id,
+                             'ds2': datastore_id})
+                raise exception.ModuleInvalid(reason=reason)
+            if (module.datastore_version_id and
+                    module.datastore_version_id != datastore_version_id):
+                reason = (_("Module '%(mod)s' cannot be applied "
+                            " (Wrong datastore version '%(ver)s' "
+                            "- expected '%(ver2)s')")
+                          % {'mod': module.name,
+                             'ver': module.datastore_version_id,
+                             'ver2': datastore_version_id})
+                raise exception.ModuleInvalid(reason=reason)
+
 
 class Module(object):
 
@@ -140,13 +161,14 @@ class Module(object):
                datastore_version, auto_apply, visible, live_update,
                priority_apply, apply_order, full_access):
         if module_type.lower() not in Modules.VALID_MODULE_TYPES:
-            LOG.error(_("Valid module types: %s") % Modules.VALID_MODULE_TYPES)
+            LOG.error(_("Valid module types: %s"), Modules.VALID_MODULE_TYPES)
             raise exception.ModuleTypeNotFound(module_type=module_type)
         Module.validate_action(
             context, 'create', tenant_id, auto_apply, visible, priority_apply,
             full_access)
-        datastore_id, datastore_version_id = Module.validate_datastore(
-            datastore, datastore_version)
+        datastore_id, datastore_version_id = (
+            datastore_models.get_datastore_or_version(
+                datastore, datastore_version))
         if Module.key_exists(
                 name, module_type, tenant_id,
                 datastore_id, datastore_version_id):
@@ -203,24 +225,6 @@ class Module(object):
                 action=action_str, options=admin_options_str)
         return admin_options_str
 
-    @staticmethod
-    def validate_datastore(datastore, datastore_version):
-        datastore_id = None
-        datastore_version_id = None
-        if datastore:
-            if datastore_version:
-                ds, ds_ver = datastore_models.get_datastore_version(
-                    type=datastore, version=datastore_version)
-                datastore_id = ds.id
-                datastore_version_id = ds_ver.id
-            else:
-                ds = datastore_models.Datastore.load(datastore)
-                datastore_id = ds.id
-        elif datastore_version:
-            msg = _("Cannot specify version without datastore")
-            raise exception.BadRequest(message=msg)
-        return datastore_id, datastore_version_id
-
     @staticmethod
     def key_exists(name, module_type, tenant_id, datastore_id,
                    datastore_version_id):
@@ -262,7 +266,7 @@ class Module(object):
             module.priority_apply, None)
         Module.enforce_live_update(module.id, module.live_update, module.md5)
         module.deleted = True
-        module.deleted_at = datetime.utcnow()
+        module.deleted_at = timeutils.utcnow()
         module.save()
 
     @staticmethod
@@ -323,7 +327,7 @@ class Module(object):
         # but we turn it on/off if full_access is specified
         if full_access is not None:
             module.is_admin = 0 if full_access else 1
-        ds_id, ds_ver_id = Module.validate_datastore(
+        ds_id, ds_ver_id = datastore_models.get_datastore_or_version(
             module.datastore_id, module.datastore_version_id)
         if module.contents != original_module.contents:
             md5, processed_contents = Module.process_contents(module.contents)
@@ -338,9 +342,15 @@ class Module(object):
         if module.datastore_version_id:
             module.datastore_version_id = ds_ver_id
 
-        module.updated = datetime.utcnow()
+        module.updated = timeutils.utcnow()
         DBModule.save(module)
 
+    @staticmethod
+    def reapply(context, id, md5, include_clustered,
+                batch_size, batch_delay, force):
+        task_api.API(context).reapply_module(
+            id, md5, include_clustered, batch_size, batch_delay, force)
+
 
 class InstanceModules(object):
 
@@ -390,13 +400,16 @@ class InstanceModule(object):
                 InstanceModule.update(context, instance_module)
             else:
                 if old_im.md5 == md5 and instance_module:
-                    LOG.debug("Found dupe IM record %s; marking as deleted "
-                              "(instance %s, module %s)." %
-                              (old_im.id, instance_id, module_id))
+                    LOG.debug("Found dupe IM record %(old_im)s; marking as "
+                              "deleted (instance %(instance_id)s, "
+                              "module %(module_id)s).",
+                              {'old_im': old_im.id, 'instance_id': instance_id,
+                               'module_id': module_id})
                 else:
-                    LOG.debug("Deleting IM record %s (instance %s, "
-                              "module %s)." %
-                              (old_im.id, instance_id, module_id))
+                    LOG.debug("Deleting IM record %(old_im)s (instance "
+                              "%(instance_id)s, module %(module_id)s).",
+                              {'old_im': old_im.id, 'instance_id': instance_id,
+                               'module_id': module_id})
                 InstanceModule.delete(context, old_im)
 
         # If we don't have an instance module, it means we need to create
@@ -411,7 +424,7 @@ class InstanceModule(object):
     @staticmethod
     def delete(context, instance_module):
         instance_module.deleted = True
-        instance_module.deleted_at = datetime.utcnow()
+        instance_module.deleted_at = timeutils.utcnow()
         instance_module.save()
 
     @staticmethod
@@ -427,7 +440,7 @@ class InstanceModule(object):
 
     @staticmethod
     def update(context, instance_module):
-        instance_module.updated = datetime.utcnow()
+        instance_module.updated = timeutils.utcnow()
         DBInstanceModule.save(instance_module)
 
 
