@@ -309,7 +309,7 @@ class QuotaEngine(object):
 
         reservations = self._driver.reserve(tenant_id, self._resources, deltas)
 
-        LOG.debug("Created reservations %(reservations)s" %
+        LOG.debug("Created reservations %(reservations)s",
                   {'reservations': reservations})
 
         return reservations
@@ -325,7 +325,7 @@ class QuotaEngine(object):
             self._driver.commit(reservations)
         except Exception:
             LOG.exception(_("Failed to commit reservations "
-                          "%(reservations)s") % {'reservations': reservations})
+                          "%(reservations)s"), {'reservations': reservations})
 
     def rollback(self, reservations):
         """Roll back reservations.
@@ -338,7 +338,7 @@ class QuotaEngine(object):
             self._driver.rollback(reservations)
         except Exception:
             LOG.exception(_("Failed to roll back reservations "
-                          "%(reservations)s") % {'reservations': reservations})
+                          "%(reservations)s"), {'reservations': reservations})
 
     @property
     def resources(self):
