@@ -18,12 +18,9 @@ import json
 from proboscis import SkipTest
 
 from trove.common.utils import generate_uuid
-from trove.tests.config import CONFIG
 from trove.tests.scenario.runners.test_runners import TestRunner
 from trove.tests.util.check import CollectionCheck
 from trove.tests.util.check import TypeCheck
-from trove.tests.util import create_dbaas_client
-from trove.tests.util.users import Requirements
 from troveclient.compat import exceptions
 
 
@@ -39,7 +36,6 @@ class ConfigurationRunner(TestRunner):
         self.non_dynamic_inst_count = 0
         self.initial_group_count = 0
         self.additional_group_count = 0
-        self.other_client = None
         self.config_id_for_inst = None
         self.config_inst_id = None
 
@@ -53,9 +49,10 @@ class ConfigurationRunner(TestRunner):
     def assert_action_on_conf_group_failure(
             self, group_values, expected_exception, expected_http_code):
         json_def = json.dumps(group_values)
+        client = self.auth_client
         self.assert_raises(
             expected_exception, expected_http_code,
-            self.auth_client.configurations.create,
+            client, client.configurations.create,
             'conf_group',
             json_def,
             'Group with Bad or Invalid entries',
@@ -132,13 +129,14 @@ class ConfigurationRunner(TestRunner):
     def assert_create_group(self, name, description, values,
                             expected_http_code):
         json_def = json.dumps(values)
-        result = self.auth_client.configurations.create(
+        client = self.auth_client
+        result = client.configurations.create(
             name,
             json_def,
             description,
             datastore=self.instance_info.dbaas_datastore,
             datastore_version=self.instance_info.dbaas_datastore_version)
-        self.assert_client_code(expected_http_code)
+        self.assert_client_code(client, expected_http_code)
 
         with TypeCheck('Configuration', result) as configuration:
             configuration.has_field('name', basestring)
@@ -273,20 +271,10 @@ class ConfigurationRunner(TestRunner):
     def assert_conf_get_unauthorized_user(
             self, config_id, expected_exception=exceptions.NotFound,
             expected_http_code=404):
-        self._create_other_client()
+        client = self.unauth_client
         self.assert_raises(
-            expected_exception, None,
-            self.other_client.configurations.get, config_id)
-        # we're using a different client, so we'll check the return code
-        # on it explicitly, instead of depending on 'assert_raises'
-        self.assert_client_code(expected_http_code, client=self.other_client)
-
-    def _create_other_client(self):
-        if not self.other_client:
-            requirements = Requirements(is_admin=False)
-            other_user = CONFIG.users.find_user(
-                requirements, black_list=[self.instance_info.user.auth_user])
-            self.other_client = create_dbaas_client(other_user)
+            expected_exception, expected_http_code,
+            client, client.configurations.get, config_id)
 
     def run_non_dynamic_conf_get_unauthorized_user(
             self, expected_exception=exceptions.NotFound,
@@ -318,6 +306,35 @@ class ConfigurationRunner(TestRunner):
                 self.instance_info.id, self.dynamic_group_id,
                 expected_states, expected_http_code)
 
+    def run_verify_dynamic_values(self):
+        if self.dynamic_group_id:
+            self.assert_configuration_values(self.instance_info.id,
+                                             self.dynamic_group_id)
+
+    def assert_configuration_values(self, instance_id, group_id):
+        if group_id == self.dynamic_group_id:
+            expected_configs = self.test_helper.get_dynamic_group()
+        elif group_id == self.non_dynamic_group_id:
+            expected_configs = self.test_helper.get_non_dynamic_group()
+
+        self._assert_configuration_values(instance_id, expected_configs)
+
+    def _assert_configuration_values(self, instance_id, expected_configs):
+        host = self.get_instance_host(instance_id)
+        for name, value in expected_configs.items():
+            actual = self.test_helper.get_configuration_value(name, host)
+            # Compare floating point numbers as floats to avoid rounding
+            # and precision issues.
+            try:
+                expected_value = float(value)
+                actual_value = float(actual)
+            except ValueError:
+                expected_value = str(value)
+                actual_value = str(actual)
+
+            self.assert_equal(expected_value, actual_value,
+                              "Unexpected value of property '%s'" % name)
+
     def run_list_dynamic_inst_conf_groups_after(self):
         if self.dynamic_group_id:
             self.assert_conf_instance_list(self.dynamic_group_id,
@@ -355,9 +372,10 @@ class ConfigurationRunner(TestRunner):
     def assert_update_group(
             self, instance_id, group_id, values,
             expected_states, expected_http_code, restart_inst=False):
-        self.auth_client.configurations.update(group_id, values)
-        self.assert_instance_action(
-            instance_id, expected_states, expected_http_code)
+        client = self.auth_client
+        client.configurations.update(group_id, values)
+        self.assert_client_code(client, expected_http_code)
+        self.assert_instance_action(instance_id, expected_states)
         if restart_inst:
             self._restart_instance(instance_id)
 
@@ -382,6 +400,11 @@ class ConfigurationRunner(TestRunner):
                 self.instance_info.id, self.non_dynamic_group_id,
                 expected_states, expected_http_code, restart_inst=True)
 
+    def run_verify_non_dynamic_values(self):
+        if self.non_dynamic_group_id:
+            self.assert_configuration_values(self.instance_info.id,
+                                             self.non_dynamic_group_id)
+
     def run_list_non_dynamic_inst_conf_groups_after(self):
         if self.non_dynamic_group_id:
             self.assert_conf_instance_list(self.non_dynamic_group_id,
@@ -423,9 +446,10 @@ class ConfigurationRunner(TestRunner):
     def assert_instance_modify(
             self, instance_id, group_id, expected_states, expected_http_code,
             restart_inst=False):
-        self.auth_client.instances.modify(instance_id, configuration=group_id)
-        self.assert_instance_action(
-            instance_id, expected_states, expected_http_code)
+        client = self.auth_client
+        client.instances.modify(instance_id, configuration=group_id)
+        self.assert_client_code(client, expected_http_code)
+        self.assert_instance_action(instance_id, expected_states)
 
         # Verify the group has been attached.
         instance = self.get_instance(instance_id)
@@ -448,9 +472,10 @@ class ConfigurationRunner(TestRunner):
     def assert_instance_modify_failure(
             self, instance_id, group_id, expected_exception,
             expected_http_code):
+        client = self.auth_client
         self.assert_raises(
             expected_exception, expected_http_code,
-            self.auth_client.instances.modify,
+            client, client.instances.modify,
             instance_id, configuration=group_id)
 
     def run_delete_dynamic_group(self, expected_http_code=202):
@@ -459,8 +484,9 @@ class ConfigurationRunner(TestRunner):
                                      expected_http_code)
 
     def assert_group_delete(self, group_id, expected_http_code):
-        self.auth_client.configurations.delete(group_id)
-        self.assert_client_code(expected_http_code)
+        client = self.auth_client
+        client.configurations.delete(group_id)
+        self.assert_client_code(client, expected_http_code)
 
     def run_delete_non_dynamic_group(self, expected_http_code=202):
         if self.non_dynamic_group_id:
@@ -469,16 +495,18 @@ class ConfigurationRunner(TestRunner):
 
     def assert_group_delete_failure(self, group_id, expected_exception,
                                     expected_http_code):
+        client = self.auth_client
         self.assert_raises(
             expected_exception, expected_http_code,
-            self.auth_client.configurations.delete, group_id)
+            client, client.configurations.delete, group_id)
 
     def _restart_instance(
             self, instance_id, expected_states=['REBOOT', 'ACTIVE'],
             expected_http_code=202):
-        self.auth_client.instances.restart(instance_id)
-        self.assert_instance_action(instance_id, expected_states,
-                                    expected_http_code)
+        client = self.auth_client
+        client.instances.restart(instance_id)
+        self.assert_client_code(client, expected_http_code)
+        self.assert_instance_action(instance_id, expected_states)
 
     def run_create_instance_with_conf(self):
         self.config_id_for_inst = (
@@ -492,41 +520,55 @@ class ConfigurationRunner(TestRunner):
 
     def assert_create_instance_with_conf(self, config_id):
         # test that a new instance will apply the configuration on create
-        result = self.auth_client.instances.create(
-            "TEST_" + str(datetime.now()) + "_config",
+        client = self.auth_client
+        result = client.instances.create(
+            self.instance_info.name + "_config",
             self.instance_info.dbaas_flavor_href,
             self.instance_info.volume,
-            [], [], availability_zone="nova",
+            [], [],
+            datastore=self.instance_info.dbaas_datastore,
+            datastore_version=self.instance_info.dbaas_datastore_version,
+            nics=self.instance_info.nics,
+            availability_zone="nova",
             configuration=config_id)
-        self.assert_client_code(200)
+        self.assert_client_code(client, 200)
         self.assert_equal("BUILD", result.status, 'Unexpected inst status')
+        self.register_debug_inst_ids(result.id)
         return result.id
 
     def run_wait_for_conf_instance(
-            # we can't specify all the states here, as it may go active
-            # before this test runs
-            self, final_state=['ACTIVE'],
-            expected_http_code=200):
+            self, expected_states=['BUILD', 'ACTIVE']):
         if self.config_inst_id:
-            self.assert_instance_action(self.config_inst_id, final_state,
-                                        expected_http_code)
+            self.assert_instance_action(self.config_inst_id, expected_states)
+            self.create_test_helper_on_instance(self.config_inst_id)
             inst = self.auth_client.instances.get(self.config_inst_id)
             self.assert_equal(self.config_id_for_inst,
                               inst.configuration['id'])
         else:
             raise SkipTest("No instance created with a configuration group.")
 
-    def run_delete_conf_instance(
-            self, expected_states=['SHUTDOWN'],
-            expected_http_code=202):
-        if self.config_inst_id:
-            self.assert_delete_conf_instance(
-                self.config_inst_id, expected_states, expected_http_code)
+    def run_verify_instance_values(self):
+        if self.config_id_for_inst:
+            self.assert_configuration_values(self.config_inst_id,
+                                             self.config_id_for_inst)
         else:
             raise SkipTest("No instance created with a configuration group.")
 
-    def assert_delete_conf_instance(
-            self, instance_id, expected_state, expected_http_code):
-        self.auth_client.instances.delete(instance_id)
-        self.assert_client_code(expected_http_code)
-        self.assert_all_gone(instance_id, expected_state)
+    def run_delete_conf_instance(self, expected_http_code=202):
+        if self.config_inst_id:
+            self.assert_delete_conf_instance(
+                self.config_inst_id, expected_http_code)
+        else:
+            raise SkipTest("No instance created with a configuration group.")
+
+    def assert_delete_conf_instance(self, instance_id, expected_http_code):
+        client = self.auth_client
+        client.instances.delete(instance_id)
+        self.assert_client_code(client, expected_http_code)
+
+    def run_wait_for_delete_conf_instance(
+            self, expected_last_state=['SHUTDOWN']):
+        if self.config_inst_id:
+            self.assert_all_gone(self.config_inst_id, expected_last_state)
+        else:
+            raise SkipTest("No instance created with a configuration group.")
