@@ -306,8 +306,7 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                                       mock_cluster_create,
                                       mock_get_datastore_version):
 
-        cfg.CONF.set_override('cluster_support', False, group='mongodb',
-                              enforce_type=True)
+        cfg.CONF.set_override('cluster_support', False, group='mongodb')
 
         body = self.cluster
         tenant_id = Mock()
@@ -332,8 +331,7 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                                      mock_get_datastore_version,
                                      mock_cluster_view_data):
 
-        cfg.CONF.set_override('cluster_support', True, group='mongodb',
-                              enforce_type=True)
+        cfg.CONF.set_override('cluster_support', True, group='mongodb')
 
         body = self.cluster
         tenant_id = Mock()
