@@ -293,8 +293,7 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                                       mock_cluster_create,
                                       mock_get_datastore_version):
 
-        cfg.CONF.set_override('cluster_support', False, group='redis',
-                              enforce_type=True)
+        cfg.CONF.set_override('cluster_support', False, group='redis')
 
         body = self.cluster
         tenant_id = Mock()
@@ -323,8 +322,7 @@ class TestClusterControllerWithStrategy(trove_testtools.TestCase):
                                      mock_get_datastore_version,
                                      mock_cluster_view_data):
 
-        cfg.CONF.set_override('cluster_support', True, group='redis',
-                              enforce_type=True)
+        cfg.CONF.set_override('cluster_support', True, group='redis')
 
         body = self.cluster
         tenant_id = Mock()
