@@ -297,8 +297,7 @@ class TestCreateCinderClient(trove_testtools.TestCase):
     def test_create_with_conf_override(self):
         cinder_url_from_conf = 'http://example.com'
         tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('cinder_url', cinder_url_from_conf,
-                              enforce_type=True)
+        cfg.CONF.set_override('cinder_url', cinder_url_from_conf)
 
         client = remote.create_cinder_client(
             TroveContext(tenant=tenant_from_ctx))
@@ -308,8 +307,7 @@ class TestCreateCinderClient(trove_testtools.TestCase):
     def test_create_with_conf_override_trailing_slash(self):
         cinder_url_from_conf = 'http://example.com/'
         tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('cinder_url', cinder_url_from_conf,
-                              enforce_type=True)
+        cfg.CONF.set_override('cinder_url', cinder_url_from_conf)
         client = remote.create_cinder_client(
             TroveContext(tenant=tenant_from_ctx))
         self.assertEqual('%s%s' % (cinder_url_from_conf, tenant_from_ctx),
@@ -322,10 +320,8 @@ class TestCreateCinderClient(trove_testtools.TestCase):
                          client.client.management_url)
 
     def test_create_with_catalog_all_opts(self):
-        cfg.CONF.set_override('cinder_service_type', 'volume',
-                              enforce_type=True)
-        cfg.CONF.set_override('os_region_name', 'RegionTwo',
-                              enforce_type=True)
+        cfg.CONF.set_override('cinder_service_type', 'volume')
+        cfg.CONF.set_override('os_region_name', 'RegionTwo')
         client = remote.create_cinder_client(
             TroveContext(service_catalog=self.service_catalog))
         self.assertEqual(self.volume_public_url_region_two,
@@ -376,8 +372,7 @@ class TestCreateNovaClient(trove_testtools.TestCase):
     def test_create_with_conf_override(self):
         nova_url_from_conf = 'http://example.com'
         tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('nova_compute_url', nova_url_from_conf,
-                              enforce_type=True)
+        cfg.CONF.set_override('nova_compute_url', nova_url_from_conf)
 
         client = remote.create_nova_client(
             TroveContext(tenant=tenant_from_ctx))
@@ -387,8 +382,7 @@ class TestCreateNovaClient(trove_testtools.TestCase):
     def test_create_with_conf_override_trailing_slash(self):
         nova_url_from_conf = 'http://example.com/'
         tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('nova_compute_url', nova_url_from_conf,
-                              enforce_type=True)
+        cfg.CONF.set_override('nova_compute_url', nova_url_from_conf)
         client = remote.create_nova_client(
             TroveContext(tenant=tenant_from_ctx))
         self.assertEqual('%s%s' % (nova_url_from_conf, tenant_from_ctx),
@@ -401,10 +395,8 @@ class TestCreateNovaClient(trove_testtools.TestCase):
                          client.client.management_url)
 
     def test_create_with_catalog_all_opts(self):
-        cfg.CONF.set_override('nova_compute_service_type', 'computev3',
-                              enforce_type=True)
-        cfg.CONF.set_override('os_region_name', 'RegionTwo',
-                              enforce_type=True)
+        cfg.CONF.set_override('nova_compute_service_type', 'computev3')
+        cfg.CONF.set_override('os_region_name', 'RegionTwo')
         client = remote.create_nova_client(
             TroveContext(service_catalog=self.service_catalog))
         self.assertEqual(self.computev3_public_url_region_two,
@@ -412,8 +404,7 @@ class TestCreateNovaClient(trove_testtools.TestCase):
 
     def test_create_admin_client(self):
         nova_url_from_conf = 'http://adminexample.com/'
-        cfg.CONF.set_override('nova_compute_url', nova_url_from_conf,
-                              enforce_type=True)
+        cfg.CONF.set_override('nova_compute_url', nova_url_from_conf)
         admin_user = 'admin1'
         admin_pass = 'adminpwd'
         admin_tenant_id = uuid.uuid4().hex
@@ -427,85 +418,6 @@ class TestCreateNovaClient(trove_testtools.TestCase):
                          admin_client.client.management_url)
 
 
-class TestCreateHeatClient(trove_testtools.TestCase):
-    def setUp(self):
-        super(TestCreateHeatClient, self).setUp()
-        self.heat_public_url = 'http://publicURL/v2'
-        self.heatv3_public_url_region_two = 'http://publicURL-r2/v3'
-        self.service_catalog = [
-            {
-                'endpoints': [
-                    {
-                        'region': 'RegionOne',
-                        'publicURL': self.heat_public_url,
-                    }
-                ],
-                'type': 'orchestration'
-            },
-            {
-                'endpoints': [
-                    {
-                        'region': 'RegionOne',
-                        'publicURL': 'http://publicURL-r1/v1',
-                    },
-                    {
-                        'region': 'RegionTwo',
-                        'publicURL': self.heatv3_public_url_region_two,
-                    }
-                ],
-                'type': 'orchestrationv3'
-            }
-        ]
-
-    def tearDown(self):
-        super(TestCreateHeatClient, self).tearDown()
-        cfg.CONF.clear_override('heat_url')
-        cfg.CONF.clear_override('heat_service_type')
-        cfg.CONF.clear_override('os_region_name')
-
-    def test_create_with_no_conf_no_catalog(self):
-        self.assertRaises(exception.EmptyCatalog,
-                          remote.create_heat_client,
-                          TroveContext())
-
-    def test_create_with_conf_override(self):
-        heat_url_from_conf = 'http://example.com'
-        tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('heat_url', heat_url_from_conf,
-                              enforce_type=True)
-
-        client = remote.create_heat_client(
-            TroveContext(tenant=tenant_from_ctx))
-        self.assertEqual('%s/%s' % (heat_url_from_conf, tenant_from_ctx),
-                         client.http_client.endpoint)
-
-    def test_create_with_conf_override_trailing_slash(self):
-        heat_url_from_conf = 'http://example.com/'
-        tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('heat_url', heat_url_from_conf,
-                              enforce_type=True)
-        client = remote.create_heat_client(
-            TroveContext(tenant=tenant_from_ctx))
-        self.assertEqual('%s%s' % (heat_url_from_conf, tenant_from_ctx),
-                         client.http_client.endpoint)
-
-    def test_create_with_catalog_and_default_service_type(self):
-        client = remote.create_heat_client(
-            TroveContext(service_catalog=self.service_catalog))
-        self.assertEqual(self.heat_public_url,
-                         client.http_client.endpoint)
-
-    def test_create_with_catalog_all_opts(self):
-        cfg.CONF.set_override('heat_service_type', 'orchestrationv3',
-                              enforce_type=True)
-        cfg.CONF.set_override('os_region_name', 'RegionTwo',
-                              enforce_type=True)
-        client = remote.create_heat_client(
-            TroveContext(service_catalog=self.service_catalog))
-        self.assertEqual(self.heatv3_public_url_region_two,
-                         client.http_client.endpoint)
-
-
 class TestCreateSwiftClient(trove_testtools.TestCase):
     def setUp(self):
         super(TestCreateSwiftClient, self).setUp()
@@ -550,8 +462,7 @@ class TestCreateSwiftClient(trove_testtools.TestCase):
     def test_create_with_conf_override(self):
         swift_url_from_conf = 'http://example.com/AUTH_'
         tenant_from_ctx = uuid.uuid4().hex
-        cfg.CONF.set_override('swift_url', swift_url_from_conf,
-                              enforce_type=True)
+        cfg.CONF.set_override('swift_url', swift_url_from_conf)
 
         client = remote.create_swift_client(
             TroveContext(tenant=tenant_from_ctx))
@@ -565,10 +476,8 @@ class TestCreateSwiftClient(trove_testtools.TestCase):
                          client.url)
 
     def test_create_with_catalog_all_opts(self):
-        cfg.CONF.set_override('swift_service_type', 'object-storev3',
-                              enforce_type=True)
-        cfg.CONF.set_override('os_region_name', 'RegionTwo',
-                              enforce_type=True)
+        cfg.CONF.set_override('swift_service_type', 'object-storev3')
+        cfg.CONF.set_override('os_region_name', 'RegionTwo')
         client = remote.create_swift_client(
             TroveContext(service_catalog=self.service_catalog))
         self.assertEqual(self.swiftv3_public_url_region_two,
