@@ -37,13 +37,17 @@ def _mock_call(cmd, timeout, version=None, user=None,
 
 class ApiTest(trove_testtools.TestCase):
     @mock.patch.object(rpc, 'get_client')
-    def setUp(self, *args):
+    @mock.patch('trove.instance.models.get_instance_encryption_key',
+                return_value='2LMDgren5citVxmSYNiRFCyFfVDjJtDaQT9LYV08')
+    def setUp(self, mock_get_encryption_key, *args):
         super(ApiTest, self).setUp()
         self.context = context.TroveContext()
         self.guest = VerticaGuestAgentAPI(self.context, 0)
+
         self.guest._call = _mock_call
         self.api = VerticaGuestAgentAPI(self.context, "instance-id-x23d2d")
         self._mock_rpc_client()
+        mock_get_encryption_key.assert_called()
 
     def test_get_routing_key(self):
         self.assertEqual('guestagent.instance-id-x23d2d',
