@@ -13,10 +13,10 @@
 # limitations under the License.
 
 from mock import Mock, patch
-from novaclient import exceptions as nova_exceptions
+from glanceclient import exc as glance_exceptions
 
 from trove.common import exception
-from trove.common import remote
+from trove.common import glance_remote
 from trove.datastore import models
 from trove.extensions.mgmt.datastores.service import DatastoreVersionController
 from trove.tests.unittests import trove_testtools
@@ -48,8 +48,8 @@ class TestDatastoreVersion(trove_testtools.TestCase):
     def tearDown(self):
         super(TestDatastoreVersion, self).tearDown()
 
-    @patch.object(remote, 'create_nova_client')
-    def test_version_create(self, mock_nova_client):
+    @patch.object(glance_remote, 'create_glance_client')
+    def test_version_create(self, mock_glance_client):
         body = {"version": {
             "datastore_name": "test_ds",
             "name": "test_vr",
@@ -62,10 +62,10 @@ class TestDatastoreVersion(trove_testtools.TestCase):
             self.req, body, self.tenant_id)
         self.assertEqual(202, output.status)
 
-    @patch.object(remote, 'create_nova_client')
+    @patch.object(glance_remote, 'create_glance_client')
     @patch.object(models.DatastoreVersion, 'load')
     def test_fail_already_exists_version_create(self, mock_load,
-                                                mock_nova_client):
+                                                mock_glance_client):
         body = {"version": {
             "datastore_name": "test_ds",
             "name": "test_new_vr",
@@ -79,12 +79,10 @@ class TestDatastoreVersion(trove_testtools.TestCase):
             "A datastore version with the name 'test_new_vr' already exists",
             self.version_controller.create, self.req, body, self.tenant_id)
 
-    @patch.object(remote, 'create_nova_client')
-    def test_fail_image_not_found_version_create(self, mock_nova_client):
-        mock_nova_client.return_value.images.get = Mock(
-            side_effect=nova_exceptions.NotFound(404,
-                                                 "Image id not found image-id"
-                                                 ))
+    @patch.object(glance_remote, 'create_glance_client')
+    def test_fail_image_not_found_version_create(self, mock_glance_client):
+        mock_glance_client.return_value.images.get = Mock(
+            side_effect=glance_exceptions.HTTPNotFound())
         body = {"version": {
             "datastore_name": "test_ds",
             "name": "test_vr",
@@ -114,7 +112,7 @@ class TestDatastoreVersion(trove_testtools.TestCase):
             exception.DatastoreVersionNotFound,
             err_msg, models.DatastoreVersion.load_by_uuid, ds_version1.id)
 
-    @patch.object(remote, 'create_nova_client')
+    @patch.object(glance_remote, 'create_glance_client')
     def test_version_update(self, mock_client):
         body = {"image": "c022f4dc-76ed-4e3f-a25e-33e031f43f8b"}
         output = self.version_controller.edit(self.req, body,
@@ -127,12 +125,10 @@ class TestDatastoreVersion(trove_testtools.TestCase):
             self.ds_version2.id)
         self.assertEqual(body['image'], test_ds_version.image_id)
 
-    @patch.object(remote, 'create_nova_client')
-    def test_version_update_fail_image_not_found(self, mock_nova_client):
-        mock_nova_client.return_value.images.get = Mock(
-            side_effect=nova_exceptions.NotFound(404,
-                                                 "Image id not found image-id"
-                                                 ))
+    @patch.object(glance_remote, 'create_glance_client')
+    def test_version_update_fail_image_not_found(self, mock_glance_client):
+        mock_glance_client.return_value.images.get = Mock(
+            side_effect=glance_exceptions.HTTPNotFound())
         body = {"image": "non-existent-image-id"}
 
         self.assertRaisesRegexp(
