@@ -11,7 +11,6 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-import datetime
 import os
 from tempfile import NamedTemporaryFile
 import uuid
@@ -23,7 +22,6 @@ from mock import Mock, MagicMock, patch, PropertyMock, call
 from novaclient import exceptions as nova_exceptions
 import novaclient.v2.flavors
 import novaclient.v2.servers
-from oslo_utils import timeutils
 from swiftclient.client import ClientException
 from testtools.matchers import Equals, Is
 
@@ -39,6 +37,7 @@ from trove.common.instance import ServiceStatuses
 from trove.common.notification import TroveInstanceModifyVolume
 from trove.common import remote
 import trove.common.template as template
+from trove.common import timeutils
 from trove.common import utils
 from trove.datastore import models as datastore_models
 import trove.db.models
@@ -59,6 +58,11 @@ INST_ID = 'dbinst-id-1'
 VOLUME_ID = 'volume-id-1'
 
 
+class _fake_neutron_client(object):
+    def list_floatingips(self):
+        return {'floatingips': [{'floating_ip_address': '192.168.10.1'}]}
+
+
 class FakeOptGroup(object):
     def __init__(self, tcp_ports=['3306', '3301-3307'],
                  udp_ports=[], icmp=False):
@@ -347,15 +351,6 @@ class FreshInstanceTasksTest(trove_testtools.TestCase):
                           self.freshinstancetasks._create_secgroup,
                           datastore_manager)
 
-    def test_create_sg_rules_greater_than_exception_raised(self):
-        datastore_manager = 'mysql'
-        self.task_models_conf_mock.get = Mock(
-            return_value=FakeOptGroup(tcp_ports=['3306', '33060-3306']))
-        self.freshinstancetasks.update_db = Mock()
-        self.assertRaises(MalformedSecurityGroupRuleError,
-                          self.freshinstancetasks._create_secgroup,
-                          datastore_manager)
-
     def test_create_sg_rules_success_with_duplicated_port_or_range(self):
         datastore_manager = 'mysql'
         self.task_models_conf_mock.get = Mock(
@@ -646,8 +641,8 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
                                  datastore_id='id-1',
                                  flavor_id='6',
                                  manager='mysql',
-                                 created=datetime.datetime.utcnow(),
-                                 updated=datetime.datetime.utcnow(),
+                                 created=timeutils.utcnow(),
+                                 updated=timeutils.utcnow(),
                                  compute_instance_id='computeinst-id-1',
                                  tenant_id='testresize-tenant-id',
                                  volume_size='1',
@@ -740,14 +735,6 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
         if 'volume' in self._testMethodName:
             self._stub_volume_client()
 
-        stub_floating_ips_manager = MagicMock(
-            spec=novaclient.v2.floating_ips.FloatingIPManager)
-        self.instance_task._nova_client.floating_ips = (
-            stub_floating_ips_manager)
-        floatingip = novaclient.v2.floating_ips.FloatingIP(
-            stub_floating_ips_manager, {'ip': '192.168.10.1'}, True)
-        stub_floating_ips_manager.list = MagicMock(return_value=[floatingip])
-
     def tearDown(self):
         super(BuiltInstanceTasksTest, self).tearDown()
 
@@ -878,14 +865,20 @@ class BuiltInstanceTasksTest(trove_testtools.TestCase):
                               Mock())
 
     def test_get_floating_ips(self):
-        floating_ips = self.instance_task._get_floating_ips()
-        self.assertEqual('192.168.10.1', floating_ips['192.168.10.1'].ip)
+        with patch.object(remote, 'create_neutron_client',
+                          return_value=_fake_neutron_client()):
+            floating_ips = self.instance_task._get_floating_ips()
+            self.assertEqual('192.168.10.1',
+                             floating_ips['192.168.10.1'].get(
+                                 'floating_ip_address'))
 
     @patch.object(BaseInstance, 'get_visible_ip_addresses',
                   return_value=['192.168.10.1'])
     def test_detach_public_ips(self, mock_address):
-        removed_ips = self.instance_task.detach_public_ips()
-        self.assertEqual(['192.168.10.1'], removed_ips)
+        with patch.object(remote, 'create_neutron_client',
+                          return_value=_fake_neutron_client()):
+            removed_ips = self.instance_task.detach_public_ips()
+            self.assertEqual(['192.168.10.1'], removed_ips)
 
     def test_attach_public_ips(self):
         self.instance_task.attach_public_ips(['192.168.10.1'])
